#
# spec file for package kdebase4-workspace
#
# Copyright (c) 2019 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


#Compat macro for new _fillupdir macro introduced in Nov 2017
%{!?_fillupdir: %global _fillupdir /var/adm/fillup-templates}

%define with_multiseat 1

Name:           kdebase4-workspace
Version:        4.11.22
Release:        lp151.9.5
Summary:        The KDE Workspace Components
License:        GPL-2.0-or-later
Group:          System/GUI/KDE
Url:            http://www.kde.org/
BuildRequires:  fdupes
BuildRequires:  kde4-filesystem
BuildRequires:  libdbusmenu-qt-devel
BuildRequires:  libkactivities-devel
BuildRequires:  libkde4-devel >= %{_kde_platform_version}
#BuildRequires:  libkdepimlibs4-devel >= %{_kde_platform_version}
BuildRequires:  libpolkit-qt-1-devel
BuildRequires:  libprison-devel
BuildRequires:  libqimageblitz-devel
BuildRequires:  libraw1394-devel
BuildRequires:  pam-devel
BuildRequires:  pciutils-devel
BuildRequires:  xz
BuildRequires:  pkgconfig(libxklavier)
%ifnarch s390 s390x
BuildRequires:  libsensors4-devel
%endif
BuildRequires:  libqjson-devel
BuildRequires:  libxcb-devel
BuildRequires:  libxml2-tools
%if %{with_multiseat}
BuildRequires:  systemd-devel
%endif
BuildRequires:  xcb-util-image-devel
BuildRequires:  xcb-util-renderutil-devel
BuildRequires:  pkgconfig(glesv2)
BuildRequires:  pkgconfig(glu)
BuildRequires:  pkgconfig(libudev)
BuildRequires:  pkgconfig(libusb-1.0)
BuildRequires:  pkgconfig(xcb-keysyms)
BuildRequires:  pkgconfig(xcomposite)
BuildRequires:  pkgconfig(xdmcp)
BuildRequires:  pkgconfig(xft)
BuildRequires:  pkgconfig(xkbcommon-x11)
BuildRequires:  pkgconfig(xkbfile)
# SLE12 doesn't provide wayland-egl
%if 0%{?suse_version} > 1230 && 0%{?is_opensuse}
BuildRequires:  wayland-devel
BuildRequires:  pkgconfig(wayland-egl)
%endif
Source0:        kde-workspace-%{version}.tar.xz
Source1:        baselibs.conf
Source2:        titlebar_decor.png
Source3:        kwin-cubecap.png
Source4:        sysconfig.displaymanager-kdm
Source5:        kdm
Source6:        kdm-logrotate
Source7:        ksysguardd.service
## KDM patches
# PATCH-FIX-OPENSUSE kdm-cope-with-new-grub.diff -- Don't look for grub-set-default, we won't need it (bnc#771545)
Patch1:         kdm-cope-with-new-grub.diff
# PATCH-FIX-OPENSUSE In O:F since r24
Patch2:         kdm-relaxed-auth.diff
Patch3:         kdm-make_it_cool.diff
# PATCH-FIX-OPENSUSE kdm-sysconfig-values.diff -- Adds syconfig support to KDM
Patch4:         kdm-sysconfig-values.diff
# PATCH-FIX-OPENSUSE kdm-wordbreak.diff -- Wraps the username if it's too long
Patch5:         kdm-wordbreak.diff
# PATCH-FIX-OPENSUSE kdm-remove-duplicated-sessions.diff -- Removes duplicate sessions from KDM session list
Patch6:         kdm-remove-duplicated-sessions.diff
# PATCH-FIX-OPENSUSE kdm-all-users-nopass.diff -- Allows the setting which enables users to login without password
Patch7:         kdm-all-users-nopass.diff
# PATCH-FIX-OPENSUSE kdm-kdmconf.diff -- Cleans up the old kdmrc file
Patch8:         kdm-kdmconf.diff
# PATCH-FIX-OPENSUSE kdm-dont-grab-mouse.diff -- Revert changes in KDM that made it also grab the mouse, which
# prevents xvkbd from working on tablet PCs (bnc#445726)
Patch9:         kdm-dont-grab-mouse.diff
# PATCH-FIX-OPENSUSE kdm-long-xserver-timeout.diff -- Increases the time KDM waits for X to start up (bnc#462478)
Patch10:        kdm-long-xserver-timeout.diff
# PATCH-FIX-OPENSUSE These three patches are workarounds for fingerprint support (bnc#533189)
Patch11:        kdm-fix-generic-greeter.diff
Patch12:        kdm-fix-labelcolors.diff
Patch13:        same-pam-generic-classic.diff
# PATCH-FIX-OPENSUSE kdm_systemd_shutdown.patch Avoid the situation where systemd would kill KDM
# which prevents reboot/shutdown (Fedora Patch)
Patch14:        kdm_systemd_shutdown.patch
# Patch from Fedora to enable plymouth support in KDM.
# Patch is based on the changes within GDM to detect running plymouth
# and issue a quit to the plymouth daemon
Patch15:        kdm_plymouth.patch
# PATCH-FIX-OPENSUSE kdm-filter-out-btrfs-snapshots.patch wbauer@tmo.at -- filter out btrfs snapshot entries from the restart menu
Patch17:        kdm-filter-out-btrfs-snapshots.patch
## Workspace patches
# PATCH-FIX-OPENSUSE startkde.diff -- Injects branded startupconfigkeys to users $KDEHOME, and adds %datadir/kde4/env
# to list of read enviroments
Patch50:        startkde.diff
# PATCH-FIX-OPENSUSE kde4-migrate.diff -- Migrates config from .kde to .kde4
Patch51:        kde4-migrate.diff
# PATCH-FIX-OPENSUSE systemsettings-desktop.diff -- Changes name of System Settings to Configure Desktop
Patch52:        systemsettings-desktop.diff
# PATCH-FIX-OPENSUSE rotate-wacom-pointers.diff -- Adds support to krandrtray that rotates wacom pointers when the display is rotated
Patch53:        rotate-wacom-pointers.diff
# PATCH-FIX-OPENSUSE plasma-branding-defaults-applets.diff -- Brands kickoff, so it uses branded start-here icon, and adds
# several applications to SystemApplications category
Patch54:        plasma-branding-defaults-applets.diff
# PATCH-FIX-OPENSUSE plasma-dashboard-leave.diff -- Makes possible to leave dashboard view with just left-click
Patch55:        plasma-dashboard-leave.diff
# PATCH-FIX-OPENSUSE plasma-kickoff-newly-collapsing.diff -- Adds several features to kickoff, e.g. recently installed category,
# and reduced menu length
Patch56:        plasma-kickoff-newly-collapsing.diff
# PATCH-FIX-OPENSUSE plasma-panel-resize-hint.diff -- Displays pixel size when resizing panel
Patch57:        plasma-panel-resize-hint.diff
# PATCH-FIX-OPENSUSE krunner-no-italics.diff -- Change italic krunner result subtext to be smaller instead of italic (kde#307344)
Patch59:        krunner-no-italics.diff
# PATCH-FIX-OPENSUSE plasma-disable-networkmanager.diff -- Makes it possible to disable it on KDE start depending on sysconfig
Patch60:        plasma-disable-networkmanager.diff
# PATCH-FIX-OPENSUSE opensuse-homepage.diff -- Makes kickoff use openSUSE homepage as default
Patch62:        opensuse-homepage.diff
# PATCH-FIX-OPENSUSE opensuse-kinfocenter.diff (created by Alin M. Elena to have some openSUSE distro info in kinfocenter)
Patch63:        opensuse-kinfocenter.diff
# PATCH-FIX-UPSTREAM klipper.diff -- fix performance issue with Klipper see https://bugs.kde.org/show_bug.cgi?id=238084
Patch64:        klipper.patch
# PATCH-FIX-UPSTREAM kdm-backend-session.patch fix type mismatch in resource handling kde#323436
Patch65:        kdm-backend-session.patch
# PATCH-FIX-OPENSUSE add-calculator-hotkey.patch -- Adds hotkey for Calculator button (bnc#726550)
Patch66:        add-calculator-hotkey.patch
# PATCH-FIX-OPENSUSE Remove the dependencies on strigi
Patch67:        remove_strigi.patch
# Taken from fedora, additional changes resubmitted to fedora
Patch71:        kde-workspace-4.11.0-kdm-logind-multiseat.patch
Patch72:        much-more-plasma-debug.patch
# PATCH-FIX-OPENSUSE systemsettings-desktop-kde4.diff -- Changes name of System Settings to Configure KDE 4 Applications
Patch73:        systemsettings-desktop-kde4.diff
# PATCH-FIX-OPENSUSE gcc6-fixes.diff -- Fix errors reported by GCC6 compiler
Patch74:        gcc6-fixes.diff
# PATCH-FIX-OPENSUSE gcc7-fix.diff boo#1031317 wbauer@tmo.at -- Fix an error reported by the GCC7 compiler
Patch75:        gcc7-fix.diff
# PATCH-FIX-OPENSUSE
Patch76:        skip-qtwebkit-parts.patch
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
Requires:       %{name}-liboxygenstyle = %{version}
# Requires /etc/xdg/menus/applications.menu (bnc#754104)
%if !0%{?is_opensuse}
Requires:       desktop-data-SLE
%else
Requires:       desktop-data-openSUSE
%endif
Requires:       kactivities4 >= 4.13.3
Requires:       kde4-kgreeter-plugins = %{version}
%if 0%{?suse_version} <= 1320 && !0%{?is_opensuse}
Requires:       kscreen < 5.3.0
%endif
Requires:       windowmanager
# patch kdm-sysconfig-values.diff requires /var/lib/xdm/authdir/authfiles (bnc#784212)
Requires:       xdm
Requires:       xmessage
Requires:       xprop
# The openSUSE-release package should always be installed, but just to make sure as that kinfocenter needs it
Requires:       %{name}-addons = %{version}
Requires:       %{name}-libs = %{version}
Requires:       distribution-release
Requires:       socat
Recommends:     kdebase4-SuSE
Recommends:     kwin
Recommends:     plasma-addons
Recommends:     plasmoid-quickaccess
Recommends:     %{name}-plasma-calendar
# bnc#845592
Recommends:     kde-gtk-config
Suggests:       kdm
Requires(pre):	permissions
%define debug_package_requires %{name} = %{version}-%{release} kdelibs4-debuginfo
Provides:       kdebase3:/opt/kde3/bin/kicker
#Ktouchpadenabler is now part of workspace
Provides:       ktouchpadenabler = %{version}
Obsoletes:      ktouchpadenabler < %{version}
#KDED Appmenu is now part of workspace
Provides:       kded-appmenu = %{version}
Obsoletes:      kded-appmenu < %{version}
Requires:       appmenu-qt > 0.2.0
Requires:       oxygen-cursors
#Akonadi plasma engine is no longer provided
Obsoletes:      kdebase4-workspace-plasma-engine-akonadi < %{version}
Provides:       kdebase4-workspace-plasma-engine-akonadi = %{version}
%kde4_runtime_requires
# libplasmaclock links to kdepimlibs
# %%kde4_pimlibs_requires
%define _dminitdir %{_kde4_prefix}/lib/X11/displaymanagers

%description
This package contains the basic packages for a K Desktop Environment
workspace.

%package -n kdm-branding-upstream
Summary:        KDE login and display manager - upstream branding
Group:          System/GUI/KDE
Provides:       kdm-branding = %{_kde_branding_version}
Requires(pre):	%fillup_prereq
Supplements:    packageand(kdm:branding-upstream)
Conflicts:      otherproviders(kdm-branding)

%description -n kdm-branding-upstream
This package contains the upstream branding for KDE's display manager
kdm.

%package -n kwin
Summary:        KDE Window Manager
Group:          System/GUI/KDE
Provides:       kde4-kwin
Provides:       windowmanager
%kde4_runtime_requires
Requires:       %{name}-liboxygenstyle >= %{version}
Provides:       kdebase3:/opt/kde3/bin/kwin

%description -n kwin
KWin is the window manager of the K desktop environment.

%package -n kde4-kgreeter-plugins
Summary:        The KDE Greeter Plugin Components
Group:          System/GUI/KDE
Provides:       windowmanager
%kde4_runtime_requires

%description -n kde4-kgreeter-plugins
This package contains the Greeter Plugins that are needed by KDM and
Screensaver unlocking

%package addons
Summary:        The KDE Workspace addons
Group:          System/GUI/KDE
Requires:       %{name}-libs = %{version}
%kde4_runtime_requires

%description addons
This package contains the files required to run the KDE4 systemsettings, and aditional
addons useful outside 4.x Plasma. They were split out for co-instability with Plasma5
and to maintain the ability to maintain settings for kdelibs4 based applications.

%package devel
Summary:        The KDE Workspace Components
Group:          Development/Libraries/KDE
Requires:       %{name}-liboxygenstyle = %{version}
Requires:       %{name}-libs = %{version}
Requires:       kwin = %{version}
Requires:       libkde4-devel >= %{_kde_platform_version}
Provides:       plasma-devel = %{_kde_platform_version}
%kde4_runtime_requires

%description devel
This package contains the basic packages for a K Desktop Environment
workspace.

%package -n kdm
Summary:        KDE login and display manager
Group:          System/GUI/KDE
Requires:       kde4-kgreeter-plugins = %{version}
Requires:       kdm-branding = %{_kde_branding_version}
Requires:       logrotate
Requires:       pam-config
Requires:       xorg-x11-server
Provides:       kdebase3-kdm = 3.5.1
Obsoletes:      kdebase3-kdm < 3.5.1
%kde4_runtime_requires

%description -n kdm
This package contains kdm, the login and session manager for KDE.

%package liboxygenstyle
Summary:        The Libraries of the oxygen-style
Group:          System/GUI/KDE
Requires:       %{name}-libs = %{version}
%kde4_runtime_requires

%description liboxygenstyle
This package contains the libraries of the oxygen style.

%package -n krandr
Summary:        KDE Screen management tools
Group:          System/GUI/KDE
%kde4_runtime_requires

%description -n krandr
KDE Screen management tools

%package -n oxygen4-cursors
Summary:        The KDE Workspace Cursors
Group:          System/GUI/KDE
Provides:       oxygen-cursors = %{version}
Obsoletes:      oxygen-cursors4 < %{version}
Provides:       oxygen-cursors4 = %{version}

%description -n oxygen4-cursors
This package contains the default cursor set for a K Desktop Environment
workspace.

%package libs
Summary:        The KDE Workspace Libraries
Group:          System/GUI/KDE
Obsoletes:      libkworkspace4
%kde4_runtime_requires

%description libs
This package contains the KDE Workspace Libraries.

%prep
%setup -q -n kde-workspace-%{version}
## KDM patches
%patch1
%patch2
%patch3
%patch4
%patch5
%patch6
%patch7
%patch8
%patch9 -p0
%patch10
%patch11
%patch12 -p1
%patch13
%patch14 -p1
%patch15 -p1
%patch17 -p1
## Workspace patches
%patch50
%patch51
%patch53
%patch54
%patch55
%patch56 -p1
%patch57
%patch59 -p1
%patch60 -p1
%patch62 -p1
%patch63 -p1
%patch64 -p1
%patch65 -p1
%patch66 -p1
%patch67 -p1
%if %{with_multiseat}
%patch71 -p1
%endif
%patch72 -p1
%if 0%{?suse_version} > 1320 || (0%{?suse_version} == 1315 && 0%{?is_opensuse})
%patch73
%else
%patch52
%endif
%patch74
%patch75 -p1
%patch76 -p1

cp %{SOURCE3} kwin/effects/cube/data/cubecap.png

%build
  EXTRA_FLAGS="-DKDE4_COMMON_PAM_SERVICE=xdm \
	-DSYSCONF_INSTALL_DIR=/etc \
	-DKDE4_ENABLE_FPIE=1"
    %cmake_kde4 -d build -- $EXTRA_FLAGS
    %make_jobs

%install
    cd build
    %kde4_makeinstall
    rm -rf %{buildroot}½{_kde4_modulesdir}/plasma_applet_calendar.so
    install -m 644 %{SOURCE2} %{buildroot}%{_kde4_appsdir}/kwin/
    mkdir -p %{buildroot}%{_fillupdir}/
    install -m 644 %{SOURCE4} %{buildroot}%{_fillupdir}/
    %create_subdir_filelist -d kdm       -v devel
    %create_subdir_filelist -d kwin      -v devel
    %create_subdir_filelist -d systemsettings -v devel
    cd ..
    sed -ri "s,.*%{_kde4_configdir}/kdm/backgroundrc,," filelists/kdm
    sed -ri "s,.*%{_kde4_configdir}/kdm/README,," filelists/kdm
    sed -ri "s,.*(%{_kde4_configdir}/kdm/kdmrc),%config(noreplace) \1," filelists/kdm
    rm -f %{buildroot}/%{_kde4_configdir}/kdm/README
    sed -ri "s,.*%{_kde4_appsdir}/kdm/themes/oxygen.*,," filelists/kdm
    sed -ri "s,.*%{_kde4_appsdir}/kdm/pics.*,," filelists/kdm
    ls -1 %{buildroot}%{_kde4_wallpapersdir}/ | while read wallpaper; \
      do test "$wallpaper" = "Horos" -o ! -d "%{buildroot}%{_kde4_wallpapersdir}/$wallpaper" \
	|| rm -r "%{buildroot}%{_kde4_wallpapersdir}/$wallpaper"; done
    mkdir -p %{buildroot}/etc
    rm -rf %{buildroot}%{_kde4_htmldir}/en/kicker
    pushd $RPM_BUILD_DIR/%buildsubdir/
    cat filelists/devel filelists/systemsettings filelists/kdm filelists/kwin | while read line; do echo "%exclude $line";done >filelists/exclude
    popd
    %suse_update_desktop_file    systemsettings X-SuSE-core
    %suse_update_desktop_file    kmenuedit      Core-Configuration
    %suse_update_desktop_file -r klipper        System TrayIcon
    %suse_update_desktop_file -r krandrtray     System TrayIcon
    mkdir -p  %{buildroot}%{_kde4_sbindir}
    mkdir -p %{buildroot}%{_kde4_sysconfdir}/init.d
    ln -sf rcxdm %{buildroot}%{_kde4_sbindir}/rckdm
    mkdir -p %{buildroot}%{_kde4_sysconfdir}/logrotate.d/
    install -m 644 %{SOURCE6} %{buildroot}%{_kde4_sysconfdir}/logrotate.d/kdm
  # Make it constant so build-compare doesn't complains. If commented postinstall
  # will generate a new one through genkdmconf.
    sed -i 's/^ForgingSeed=[0-9]\+/#ForgingSeed=1111122222/' %{buildroot}%{_kde4_configdir}/kdm/kdmrc
    mkdir -p %{buildroot}%{_dminitdir}/
    cp %{SOURCE5} %{buildroot}%{_dminitdir}/
    mkdir -p %{buildroot}%{_sysconfdir}/alternatives
    touch %{buildroot}%{_sysconfdir}/alternatives/default-displaymanager
    ln -s %{_sysconfdir}/alternatives/default-displaymanager %{buildroot}%{_dminitdir}/default-displaymanager

    %fdupes -s %{buildroot}
    %kde_post_install

%clean
    rm -rf %{buildroot}
    rm -rf filelists

%verifyscript
%verify_permissions -e %{_kde4_libexecdir}/kcheckpass

%post
/sbin/ldconfig
%set_permissions %{_kde4_libexecdir}/kcheckpass

%postun -p /sbin/ldconfig

%post -n kdm
%{_kde4_bindir}/genkdmconf
%{remove_and_set -n displaymanager KDM_SHUTDOWN}
if test -n "$KDM_SHUTDOWN" -a "$KDM_SHUTDOWN" != "no"; then
  if test "$KDM_SHUTDOWN" = "local" ; then
    KDM_SHUTDOWN=all
  fi
  case "$KDM_SHUTDOWN" in
  "auto" | "none" | "root")
    sed -i -e "s/^DISPLAYMANAGER_SHUTDOWN=.*/DISPLAYMANAGER_SHUTDOWN=\"$KDM_SHUTDOWN\"/" %{_kde4_sysconfdir}/sysconfig/displaymanager
    ;;
  esac
fi
/sbin/ldconfig
%{_sbindir}/update-alternatives --install %{_dminitdir}/default-displaymanager \
  default-displaymanager %{_dminitdir}/kdm 15

%postun -n kdm
/sbin/ldconfig
[ -f %{_dminitdir}/kdm ] || %{_sbindir}/update-alternatives \
  --remove default-displaymanager %{_dminitdir}/kdm

%post -n kdm-branding-upstream
%{fillup_only -n displaymanager -s kdm}

%pre
rm -rf %{_kde4_appsdir}/ksmserver/ksmserver.notifyrc/

%post   -n kwin -p /sbin/ldconfig

%postun -n kwin -p /sbin/ldconfig

%post   liboxygenstyle -p /sbin/ldconfig

%postun liboxygenstyle -p /sbin/ldconfig

%post   libs -p /sbin/ldconfig

%postun libs -p /sbin/ldconfig

%files -n kde4-kgreeter-plugins
%defattr(-,root,root)
%{_kde4_modulesdir}/kgreet_*.so

%files -n kdm -f filelists/kdm
%defattr(-,root,root)
%license COPYING COPYING.DOC
%doc README
%config %{_kde4_sysconfdir}/dbus-1/system.d/org.kde.kcontrol.kcmkdm.conf
%config %{_kde4_sysconfdir}/logrotate.d/kdm
%dir %{_dminitdir}
%dir %{_kde4_appsdir}/doc
%dir %{_kde4_appsdir}/doc/kdm
%dir %{_kde4_appsdir}/kdm
%dir %{_kde4_configdir}/kdm
%dir %{_kde4_wallpapersdir}
%lang(en) %{_kde4_htmldir}/en/kdm
%{_dminitdir}/kdm
%{_dminitdir}/default-displaymanager
%ghost %{_sysconfdir}/alternatives/default-displaymanager
%{_kde4_configdir}/kdm.knsrc
%{_kde4_sbindir}/rckdm

%files -n kdm-branding-upstream
%defattr(-,root,root)
%license COPYING
%config(noreplace) %{_kde4_configdir}/kdm/backgroundrc
%{_kde4_appsdir}/kdm/pics
%{_fillupdir}/sysconfig.displaymanager-kdm

%files -n kwin -f filelists/kwin
%defattr(-,root,root)
%license COPYING COPYING.DOC
%doc README kwin/clients/aurorae/theme-description
%dir %{_kde4_servicesdir}/kwin
%{_kde4_appsdir}/kwin/cubecap.png
%{_kde4_appsdir}/kwin/titlebar_decor.png
%exclude %{_kde4_datadir}/dbus-1/interfaces/org.kde.KWin.xml
%exclude %{_kde4_libdir}/libkdecorations.so*
%exclude %{_kde4_bindir}/oxygen-shadow-demo
%exclude %{_kde4_modulesdir}/kwin3_oxygen.so
%exclude %{_kde4_modulesdir}/kwin_oxygen_config.so
%exclude %{_kde4_appsdir}/kconf_update/oxygen.upd
%exclude %{_kde4_appsdir}/kconf_update/update_oxygen.pl
%exclude %{_kde4_appsdir}/kwin/oxygenclient.desktop
%{_kde4_appsdir}/kwin/default_rules/plasma_desktop_containment.kwinrules

%files liboxygenstyle
%defattr(-,root,root)
%license COPYING COPYING.DOC
%doc README
%dir %{_kde4_modulesdir}/plugins/styles
%{_kde4_bindir}/oxygen-demo
%{_kde4_bindir}/oxygen-settings
%{_kde4_bindir}/oxygen-shadow-demo
%{_kde4_libdir}/liboxygenstyle.so.*
%{_kde4_libdir}/liboxygenstyleconfig.so.*
%{_kde4_modulesdir}/kstyle_oxygen_config.so
%{_kde4_modulesdir}/plugins/styles/oxygen.so
%{_kde4_modulesdir}/kwin3_oxygen.so
%{_kde4_modulesdir}/kwin_oxygen_config.so
%dir %{_kde4_appsdir}/kstyle
%dir %{_kde4_appsdir}/kstyle/themes
%{_kde4_appsdir}/kstyle/themes/oxygen.themerc
%dir %{_kde4_appsdir}/kconf_update
%{_kde4_appsdir}/kconf_update/oxygen.upd
%{_kde4_appsdir}/kconf_update/update_oxygen.pl
%dir %{_kde4_appsdir}/kwin
%{_kde4_appsdir}/kwin/oxygenclient.desktop

%files devel -f filelists/devel
%defattr(-,root,root)
%license COPYING COPYING.DOC
%doc README
%{_kde4_appsdir}/cmake
%{_kde4_datadir}/dbus-1/interfaces/
%{_kde4_includedir}/*
%{_kde4_libdir}/cmake/KDE4Workspace/
%{_kde4_libdir}/libkdecorations.so
%{_kde4_libdir}/libkephal.so
%{_kde4_libdir}/libkfontinst.so
%{_kde4_libdir}/libkfontinstui.so
%{_kde4_libdir}/libkscreensaver.so
%{_kde4_libdir}/libksgrd.so
%{_kde4_libdir}/libkworkspace.so
%{_kde4_libdir}/liblsofui.so
%{_kde4_libdir}/liboxygenstyle.so
%{_kde4_libdir}/liboxygenstyleconfig.so
%{_kde4_libdir}/libplasma-geolocation-interface.so
%{_kde4_libdir}/libplasma_applet-system-monitor.so
%{_kde4_libdir}/libplasmaclock.so
%{_kde4_libdir}/libplasmagenericshell.so
%{_kde4_libdir}/libpowerdevilconfigcommonprivate.so
%{_kde4_libdir}/libpowerdevilcore.so
%{_kde4_libdir}/libpowerdevilui.so
%{_kde4_libdir}/libprocesscore.so
%{_kde4_libdir}/libsystemsettingsview.so
%{_kde4_libdir}/libtaskmanager.so
%{_kde4_libdir}/libweather_ion.so
%{_kde4_modulesdir}/plugins/designer/ksysguardlsofwidgets.so

%files addons -f filelists/systemsettings
%defattr(-,root,root)
%license COPYING
%doc README
%{_kde4_modulesdir}/kcm*.so
%{_kde4_modulesdir}/kded_appmenu.so
%{_kde4_modulesdir}/kded_freespacenotifier.so
%{_kde4_modulesdir}/kded_keyboard.so
%{_kde4_modulesdir}/kded_khotkeys.so
%{_kde4_modulesdir}/kded_ktouchpadenabler.so
%{_kde4_modulesdir}/kded_kwrited.so
%{_kde4_modulesdir}/kded_statusnotifierwatcher.so
%{_kde4_modulesdir}/kstyle*.so
%{_kde4_modulesdir}/plugins/styles/
%{_kde4_servicesdir}/style.desktop
%{_kde4_servicesdir}/screensaver.desktop
%{_kde4_servicesdir}/kcm_infosummary.desktop
%{_kde4_servicesdir}/dma.desktop
%{_kde4_servicesdir}/mouse.desktop
%{_kde4_servicesdir}/interrupts.desktop
%{_kde4_servicesdir}/ksplashthememgr.desktop
%{_kde4_servicesdir}/kcm_pci.desktop
%{_kde4_servicesdir}/kcm_keyboard.desktop
%{_kde4_servicesdir}/opengl.desktop
%{_kde4_servicesdir}/autostart.desktop
%{_kde4_servicesdir}/fontinst.desktop
%{_kde4_servicesdir}/ioports.desktop
%{_kde4_servicesdir}/kcmsmserver.desktop
%{_kde4_servicesdir}/nic.desktop
%{_kde4_servicesdir}/joystick.desktop
%{_kde4_servicesdir}/solid-actions.desktop
%{_kde4_servicesdir}/keys.desktop
%{_kde4_servicesdir}/devinfo.desktop
%{_kde4_servicesdir}/workspaceoptions.desktop
%{_kde4_servicesdir}/cursortheme.desktop
%{_kde4_servicesdir}/display.desktop
%{_kde4_servicesdir}/standard_actions.desktop
%{_kde4_servicesdir}/clock.desktop
%{_kde4_servicesdir}/kcmlaunch.desktop
%{_kde4_servicesdir}/scsi.desktop
%{_kde4_servicesdir}/desktoppath.desktop
%{_kde4_servicesdir}/fonts.desktop
%{_kde4_servicesdir}/desktoptheme.desktop
%{_kde4_servicesdir}/xserver.desktop
%{_kde4_servicesdir}/khotkeys.desktop
%{_kde4_servicesdir}/bell.desktop
%{_kde4_servicesdir}/colors.desktop
%{_kde4_servicesdir}/kcmaccess.desktop
%{_kde4_servicesdir}/kcm_memory.desktop
%{_kde4_servicesdir}/kcmview1394.desktop
%{_kde4_servicesdir}/smbstatus.desktop
%dir %{_kde4_servicesdir}/kded
%{_kde4_servicesdir}/kded/appmenu.desktop
%{_kde4_servicesdir}/kded/khotkeys.desktop
%{_kde4_servicesdir}/kded/kwrited.desktop
%{_kde4_servicesdir}/kded/statusnotifierwatcher.desktop
%{_kde4_servicesdir}/kded/freespacenotifier.desktop
%{_kde4_servicesdir}/kded/keyboard.desktop
%{_kde4_servicesdir}/kded/ktouchpadenabler.desktop
%{_kde4_appsdir}/kstyle/
%{_kde4_appsdir}/kcmstyle/
%{_kde4_appsdir}/color-schemes/
%{_kde4_appsdir}/kaccess/
%{_kde4_appsdir}/kcmkeyboard/
%{_kde4_appsdir}/kcmusb/
%{_kde4_appsdir}/kfontview/
%{_kde4_appsdir}/ksplash/
%{_kde4_appsdir}/desktoptheme/
%{_kde4_appsdir}/kcmkeys/
%{_kde4_appsdir}/kcmview1394/
%{_kde4_appsdir}/kdisplay/
%{_kde4_appsdir}/khotkeys/
%{_kde4_appsdir}/konqsidebartng/
%{_kde4_appsdir}/kthememanager/
%{_kde4_appsdir}/freespacenotifier/
%{_kde4_appsdir}/kcminput/
%{_kde4_appsdir}/kcmsolidactions/
%{_kde4_appsdir}/ksmserver/
%{_kde4_appsdir}/kwrited/
%{_kde4_appsdir}/solid/
%dir %{_kde4_configkcfgdir}
%{_kde4_configkcfgdir}/freespacenotifier.kcfg
%dir %{_kde4_configdir}
%config %{_kde4_configdir}/activities.knsrc
%config %{_kde4_configdir}/colorschemes.knsrc
%config %{_kde4_configdir}/kfontinst.knsrc
%config %{_kde4_configdir}/ksplash.knsrc
%config %{_kde4_configdir}/plasma-themes.knsrc
%config %{_kde4_configdir}/wallpaper.knsrc
%config %{_kde4_configdir}/xcursor.knsrc
%exclude %{_kde4_libdir}/libsystemsettingsview.so.*
%exclude %{_kde4_modulesdir}/kcm_kwin*.so
%exclude %{_kde4_modulesdir}/kcm_kdm.so
%exclude %{_kde4_modulesdir}/kcm_randr.so
%exclude %{_kde4_modulesdir}/plugins/styles/oxygen.so
%exclude %{_kde4_modulesdir}/kstyle_oxygen_config.so
%exclude %{_kde4_appsdir}/kstyle/themes/oxygen.themerc

%files -n krandr
%defattr(-,root,root)
%license COPYING
%doc README
%{_kde4_applicationsdir}/krandrtray.desktop
%{_kde4_bindir}/krandrstartup
%{_kde4_bindir}/krandrtray
%{_kde4_modulesdir}/kcm_randr.so
%{_kde4_modulesdir}/kded_randrmonitor.so
%{_kde4_servicesdir}/kded/randrmonitor.desktop
%{_kde4_servicesdir}/randr.desktop

%files -f filelists/exclude
%defattr(-,root,root)
#positives
%license COPYING COPYING.DOC
%doc README
%doc %lang(en) %{_kde4_htmldir}/en/
%attr(-, root, shadow) %{_kde4_libexecdir}/kcheckpass
%config %{_kde4_sysconfdir}/dbus-1/system.d/org.kde.*
%{_kde4_applicationsdir}/
%{_kde4_appsdir}/
%{_kde4_bindir}/*
%{_kde4_configdir}/
%dir %{_kde4_configkcfgdir}
%{_kde4_configkcfgdir}/plasma-shell-desktop.kcfg
%{_kde4_datadir}/autostart/
%{_kde4_datadir}/dbus-1/services/
%{_kde4_datadir}/dbus-1/system-services/
%{_kde4_datadir}/polkit-1/
%{_kde4_iconsdir}/hicolor/*/*/*
%{_kde4_iconsdir}/oxygen/*/*
%{_kde4_libdir}/*.so
%{_kde4_libdir}/*.so.*
%{_kde4_libdir}/kconf_update_bin/
%{_kde4_modulesdir}/
%{_kde4_sharedir}/services/
%{_kde4_sharedir}/servicetypes/
%{_kde4_appsdir}/plasma-desktop/init
%{_kde4_appsdir}/plasma-netbook/init
%{_kde4_appsdir}/plasma/layout-templates

#blacklist
%exclude %{_kde4_appsdir}/kwin/default_rules/plasma_desktop_containment.kwinrules
%exclude %{_kde4_applicationsdir}/krandrtray.desktop
%exclude %{_kde4_appsdir}/cmake
%exclude %{_kde4_appsdir}/doc
%exclude %{_kde4_appsdir}/doc/kdm
%exclude %{_kde4_appsdir}/kstyle
%exclude %{_kde4_appsdir}/kcmstyle
%exclude %{_kde4_appsdir}/kdm
%exclude %{_kde4_appsdir}/kwin/cubecap.png
%exclude %{_kde4_appsdir}/kwin/titlebar_decor.png
%exclude %{_kde4_appsdir}/color-schemes/
%exclude %{_kde4_appsdir}/kaccess/
%exclude %{_kde4_appsdir}/kcmkeyboard/
%exclude %{_kde4_appsdir}/kcmusb/
%exclude %{_kde4_appsdir}/kfontview/
%exclude %{_kde4_appsdir}/ksplash/
%exclude %{_kde4_appsdir}/desktoptheme/
%exclude %{_kde4_appsdir}/kcmkeys/
%exclude %{_kde4_appsdir}/kcmview1394/
%exclude %{_kde4_appsdir}/kdisplay/
%exclude %{_kde4_appsdir}/khotkeys/
%exclude %{_kde4_appsdir}/konqsidebartng/
%exclude %{_kde4_appsdir}/kthememanager/
%exclude %{_kde4_appsdir}/freespacenotifier/
%exclude %{_kde4_appsdir}/kcminput/
%exclude %{_kde4_appsdir}/kcmsolidactions/
%exclude %{_kde4_appsdir}/ksmserver/
%exclude %{_kde4_appsdir}/kwrited/
%exclude %{_kde4_appsdir}/solid/
%exclude %{_kde4_bindir}/krandrstartup
%exclude %{_kde4_bindir}/krandrtray
%exclude %{_kde4_bindir}/oxygen-demo
%exclude %{_kde4_bindir}/oxygen-settings
%exclude %{_kde4_configdir}/kdm
%exclude %{_kde4_configdir}/kdm/backgroundrc
%exclude %{_kde4_configdir}/activities.knsrc
%exclude %{_kde4_configdir}/colorschemes.knsrc
%exclude %{_kde4_configdir}/kfontinst.knsrc
%exclude %{_kde4_configdir}/ksplash.knsrc
%exclude %{_kde4_configdir}/plasma-themes.knsrc
%exclude %{_kde4_configdir}/wallpaper.knsrc
%exclude %{_kde4_configdir}/xcursor.knsrc
%exclude %{_kde4_htmldir}/en/kdm
%exclude %{_kde4_libdir}/libkephal.so
%exclude %{_kde4_libdir}/libkephal.so.*
%exclude %{_kde4_libdir}/libkfontinst.so
%exclude %{_kde4_libdir}/libkfontinst.so.*
%exclude %{_kde4_libdir}/libkfontinstui.so
%exclude %{_kde4_libdir}/libkfontinstui.so.*
%exclude %{_kde4_libdir}/libkscreensaver.so
%exclude %{_kde4_libdir}/libkscreensaver.so.*
%exclude %{_kde4_libdir}/libksgrd.so
%exclude %{_kde4_libdir}/libksgrd.so.*
%exclude %{_kde4_libdir}/libkworkspace.so
%exclude %{_kde4_libdir}/libkworkspace.so.*
%exclude %{_kde4_libdir}/liblsofui.so
%exclude %{_kde4_libdir}/liblsofui.so.*
%exclude %{_kde4_libdir}/liboxygenstyle.*
%exclude %{_kde4_libdir}/liboxygenstyleconfig.so
%exclude %{_kde4_libdir}/liboxygenstyleconfig.so.*
%exclude %{_kde4_libdir}/libplasma-geolocation-interface.so
%exclude %{_kde4_libdir}/libplasma-geolocation-interface.so.*
%exclude %{_kde4_libdir}/libplasma_applet-system-monitor.so
%exclude %{_kde4_libdir}/libplasma_applet-system-monitor.so.*
%exclude %{_kde4_libdir}/libplasmaclock.so
%exclude %{_kde4_libdir}/libplasmaclock.so.*
%exclude %{_kde4_libdir}/libplasmagenericshell.so
%exclude %{_kde4_libdir}/libplasmagenericshell.so.*
%exclude %{_kde4_libdir}/libpowerdevilconfigcommonprivate.so
%exclude %{_kde4_libdir}/libpowerdevilconfigcommonprivate.so.*
%exclude %{_kde4_libdir}/libpowerdevilcore.so
%exclude %{_kde4_libdir}/libpowerdevilcore.so.*
%exclude %{_kde4_libdir}/libpowerdevilui.so
%exclude %{_kde4_libdir}/libpowerdevilui.so.*
%exclude %{_kde4_libdir}/libprocesscore.so
%exclude %{_kde4_libdir}/libprocesscore.so.*
%exclude %{_kde4_libdir}/libsystemsettingsview.so
%exclude %{_kde4_libdir}/libsystemsettingsview.so.*
%exclude %{_kde4_libdir}/libtaskmanager.so
%exclude %{_kde4_libdir}/libtaskmanager.so.*
%exclude %{_kde4_libdir}/libweather_ion.so
%exclude %{_kde4_libdir}/libweather_ion.so.*
%exclude %{_kde4_libdir}/libkhotkeysprivate.so.*
%exclude %{_kde4_modulesdir}/kcm_kdm.so
%exclude %{_kde4_modulesdir}/kcm_randr.so
%exclude %{_kde4_modulesdir}/kcm*.so
%exclude %{_kde4_modulesdir}/kded_appmenu.so
%exclude %{_kde4_modulesdir}/kded_freespacenotifier.so
%exclude %{_kde4_modulesdir}/kded_keyboard.so
%exclude %{_kde4_modulesdir}/kded_khotkeys.so
%exclude %{_kde4_modulesdir}/kded_ktouchpadenabler.so
%exclude %{_kde4_modulesdir}/kded_kwrited.so
%exclude %{_kde4_modulesdir}/kded_statusnotifierwatcher.so
%exclude %{_kde4_modulesdir}/kstyle*.so
%exclude %{_kde4_modulesdir}/kded_randrmonitor.so
%exclude %{_kde4_modulesdir}/kgreet_*.so
%exclude %{_kde4_modulesdir}/kstyle_oxygen_config.so
%exclude %{_kde4_modulesdir}/plugins/designer/ksysguardlsofwidgets.so
%exclude %{_kde4_modulesdir}/plugins/styles
%exclude %{_kde4_modulesdir}/plugins/styles/oxygen.so
%exclude %{_kde4_modulesdir}/plugins/gui_platform
%exclude %{_kde4_modulesdir}/plugins/gui_platform/libkde.so
%exclude %{_kde4_servicesdir}/kded/randrmonitor.desktop
%exclude %{_kde4_servicesdir}/kwin
%exclude %{_kde4_servicesdir}/randr.desktop
%exclude %{_kde4_servicesdir}/style.desktop
%exclude %{_kde4_servicesdir}/screensaver.desktop
%exclude %{_kde4_servicesdir}/kcm_infosummary.desktop
%exclude %{_kde4_servicesdir}/dma.desktop
%exclude %{_kde4_servicesdir}/mouse.desktop
%exclude %{_kde4_servicesdir}/interrupts.desktop
%exclude %{_kde4_servicesdir}/ksplashthememgr.desktop
%exclude %{_kde4_servicesdir}/kcm_pci.desktop
%exclude %{_kde4_servicesdir}/kcm_keyboard.desktop
%exclude %{_kde4_servicesdir}/opengl.desktop
%exclude %{_kde4_servicesdir}/autostart.desktop
%exclude %{_kde4_servicesdir}/fontinst.desktop
%exclude %{_kde4_servicesdir}/ioports.desktop
%exclude %{_kde4_servicesdir}/kcmsmserver.desktop
%exclude %{_kde4_servicesdir}/nic.desktop
%exclude %{_kde4_servicesdir}/joystick.desktop
%exclude %{_kde4_servicesdir}/solid-actions.desktop
%exclude %{_kde4_servicesdir}/keys.desktop
%exclude %{_kde4_servicesdir}/devinfo.desktop
%exclude %{_kde4_servicesdir}/workspaceoptions.desktop
%exclude %{_kde4_servicesdir}/cursortheme.desktop
%exclude %{_kde4_servicesdir}/display.desktop
%exclude %{_kde4_servicesdir}/standard_actions.desktop
%exclude %{_kde4_servicesdir}/clock.desktop
%exclude %{_kde4_servicesdir}/kcmlaunch.desktop
%exclude %{_kde4_servicesdir}/scsi.desktop
%exclude %{_kde4_servicesdir}/desktoppath.desktop
%exclude %{_kde4_servicesdir}/fonts.desktop
%exclude %{_kde4_servicesdir}/desktoptheme.desktop
%exclude %{_kde4_servicesdir}/xserver.desktop
%exclude %{_kde4_servicesdir}/khotkeys.desktop
%exclude %{_kde4_servicesdir}/bell.desktop
%exclude %{_kde4_servicesdir}/colors.desktop
%exclude %{_kde4_servicesdir}/kcmaccess.desktop
%exclude %{_kde4_servicesdir}/kcm_memory.desktop
%exclude %{_kde4_servicesdir}/kcmview1394.desktop
%exclude %{_kde4_servicesdir}/smbstatus.desktop
%exclude %{_kde4_servicesdir}/kded/appmenu.desktop
%exclude %{_kde4_servicesdir}/kded/khotkeys.desktop
%exclude %{_kde4_servicesdir}/kded/kwrited.desktop
%exclude %{_kde4_servicesdir}/kded/statusnotifierwatcher.desktop
%exclude %{_kde4_servicesdir}/kded/freespacenotifier.desktop
%exclude %{_kde4_servicesdir}/kded/keyboard.desktop
%exclude %{_kde4_servicesdir}/kded/ktouchpadenabler.desktop
%exclude %{_kde4_sysconfdir}/dbus-1/system.d/org.kde.kcontrol.kcmkdm.conf
%exclude %{_fillupdir}/sysconfig.displaymanager-kdm

%files -n oxygen4-cursors
%defattr(-,root,root)
%license COPYING
%doc README
%{_kde4_iconsdir}/Oxygen_*/
%{_kde4_iconsdir}/KDE_Classic/

%files libs
%defattr(-,root,root)
%license COPYING
%doc README
%{_kde4_libdir}/libkdecorations.so.*
%{_kde4_libdir}/libkephal.so.*
%{_kde4_libdir}/libkfontinst.so.*
%{_kde4_libdir}/libkfontinstui.so.*
%{_kde4_libdir}/libkscreensaver.so.*
%{_kde4_libdir}/libksgrd.so.*
%{_kde4_libdir}/libkworkspace.so.*
%{_kde4_libdir}/liblsofui.so.*
%{_kde4_libdir}/libplasma-geolocation-interface.so.*
%{_kde4_libdir}/libplasma_applet-system-monitor.so.*
%{_kde4_libdir}/libplasmaclock.so.*
%{_kde4_libdir}/libplasmagenericshell.so.*
%{_kde4_libdir}/libpowerdevilconfigcommonprivate.so.*
%{_kde4_libdir}/libpowerdevilcore.so.*
%{_kde4_libdir}/libpowerdevilui.so.*
%{_kde4_libdir}/libprocesscore.so.*
%{_kde4_libdir}/libsystemsettingsview.so.*
%{_kde4_libdir}/libtaskmanager.so.*
%{_kde4_libdir}/libweather_ion.so.*
%{_kde4_libdir}/libkhotkeysprivate.so.*
%{_kde4_modulesdir}/plugins/gui_platform/

%changelog
* Tue Mar 26 2019 Christophe Giboudeaux <christophe@krop.fr>
- Remove the last %%kde4_pimlibs_requires line.
  Nothing should require kdepimlibs4 anymore.
* Tue Nov 27 2018 Luca Beltrame <lbeltrame@kde.org>
- Remove gpsd-devel BuildRequires, not only it breaks with latest
  gpsd, but it is also completely unused (Plasma 4.x is no longer
  present in any supported openSUSE version)
* Tue Feb 27 2018 dimstar@opensuse.org
- Use SPDX3.0 license tags and package COPYING as %%license.
* Tue Feb 27 2018 fabian@ritter-vogt.de
- Add explicit BuildReq: pkgconfig(xkbcommon-x11), (xkbfile),
  (xcomposite), (xdmcp) and (xft)
* Wed Jan  3 2018 fabian@ritter-vogt.de
- Remove Requires: polkit-kde-agent-1 as it got dropped
* Mon Dec 11 2017 tittiatcoke@gmail.com
- Drop the build of python-kdebase4 as that python-kde4 is no
  longer available
* Sat Dec  2 2017 fabian@ritter-vogt.de
- Add patch to not build against Qt4 WebKit:
  * skip-qtwebkit-parts.patch
  * Drop ksysguard, not built anymore
  * Adjust filelist
* Thu Nov 23 2017 rbrown@suse.com
- Replace references to /var/adm/fillup-templates with new
  %%_fillupdir macro (boo#1069468)
* Wed Oct 18 2017 wbauer@tmo.at
- Have update-alternatives handle Xinit's integration of the
  displaymanager, replacing /etc/sysconfig/displaymanager
  (boo#1053863)
* Wed Aug 30 2017 fabian@ritter-vogt.de
- Don't BuildRequire qalculate to fix building
  (no point in fixing)
* Wed May 17 2017 fabian@ritter-vogt.de
- Update gcc7-fix.diff to fix another error reported by GCC7
* Mon Apr  3 2017 wbauer@tmo.at
- Add gcc7-fix.diff to fix an error reported by GCC7 (boo#1031317)
* Wed May 25 2016 wbauer@tmo.at
- Changed kdm-sysconfig-values.diff:
  Add "-listen tcp" to the Xserver cmdline for Xorg 1.17 and up if
  DISPLAYMANAGER_XSERVER_TCP_PORT_6000_OPEN="yes" in
  /etc/syconfig/displaymanager, newer versions have -nolisten as
  default (boo#978262)
* Tue May 24 2016 martin.liska@suse.com
- Add patch  gcc6-fixes.diff to fix errors reported by GCC6 compiler
* Wed Jan 20 2016 tittiatcoke@gmail.com
- Drop the upstream branding package for workspace. This is no
  longer required. Move the files from the upstream branding
  package to the workspace package.
* Sun Dec  6 2015 p.drouand@gmail.com
- Replace libusb-devel with pkgconfig(libusb-1.0); ensure
  kdebase4-workspace build against libusb-1.0
* Tue Nov 10 2015 wbauer@tmo.at
- Apply systemsettings-desktop-kde4.diff (instead of
  systemsettings-desktop.diff) on Leap too (boo#954252)
* Sun Oct 11 2015 hrvoje.senjan@gmail.com
- Require kscreen only on older releases
- Devel subpackage doesn't need main subpackage
* Wed Oct  7 2015 alarrosa@suse.com
- Changed usage of %%{is_opensuse} to work when not defined
* Wed Sep  2 2015 alarrosa@suse.com
- When in SLE12, require desktop-data-SLE instead of desktop-data-openSUSE
* Tue Sep  1 2015 alarrosa@suse.com
- SLE12 doesn't provide waylang-egl so don't require it
* Mon Aug 24 2015 tittiatcoke@gmail.com
- Update to 4.11.22
  * KDE Applications 15.08.0
  * https://www.kde.org/announcements/announce-applications-15.08.0.php
- Drop upstreamed patch kdm-fix-input-focus.patch
* Mon Jul 13 2015 wbauer@tmo.at
- Add kdm-filter-out-btrfs-snapshots.patch: filter out btrfs snapshot
  entries from the restart menu
* Mon Jul  6 2015 tittiatcoke@gmail.com
- Update to 4.11.21
  * KDE Applications 15.04.3
  * https://www.kde.org/announcements/announce-applications-15.04.3.php
* Mon Jun 22 2015 tittiatcoke@gmail.com
- Correct naming of oxygen-cursors4 to be consistent with its Plasma5
  based package oxygen5-cursors
* Sat May 30 2015 tittiatcoke@gmail.com
- Update to 4.11.20
  * KDE Applications 15.04.2
  * https://www.kde.org/announcements/announce-applications-15.04.2.php
* Mon May 18 2015 hrvoje.senjan@gmail.com
- Add systemsettings-desktop-kde4.diff: Changes name of System Settings
  to Configure KDE 4 Applications, apply it for openSUSE > 13.2
- Apply systemsettings-desktop.diff only for <= 13.2
* Mon May 11 2015 tittiatcoke@gmail.com
- Update to 4.11.19
  * KDE Applications 15.04.1
  * https://www.kde.org/announcements/announce-applications-15.04.1.php
* Tue Apr 28 2015 hrvoje.senjan@gmail.com
- Require kscreen < 5.3.0
* Sat Apr 11 2015 tittiatcoke@gmail.com
- Update to 4.11.18
  * KDE Applications 15.04.0
  * See https://www.kde.org/announcements/announce-applications-15.04.0.php
* Wed Mar 25 2015 coolo@suse.com
- give more debug output in plasma - in hope to get some clue for the
  first_boot problems in openQA. Should be removed before release - hopefully
  we found the bug by then :(
  added much-more-plasma-debug.patch
* Tue Mar  3 2015 tittiatcoke@gmail.com
- Update to 4.11.17
  * KDE Applications 14.12.3
  * See https://www.kde.org/announcements/announce-applications-14.12.3.php
* Sun Feb  1 2015 tittiatcoke@gmail.com
- Update to 4.11.16
  * KDE Applications 14.12.2
  * See https://www.kde.org/announcements/announce-applications-14.12.2.php
* Mon Jan 12 2015 tittiatcoke@gmail.com
- Update to 4.11.15
  * KDE Applications 14.12.1
  * See https://www.kde.org/announcements/announce-applications-14.12.1.php
- Drop upstreamed patch kcm-fix-105797-fontconfig.patch
* Wed Dec 17 2014 wbauer@tmo.at
- Added kdm-fix-input-focus.patch: fixes keyboard input in kdm's
  dialogs (boo#772344, kde#338018)
* Thu Nov 13 2014 tittiatcoke@gmail.com
- Recommend the plasma-calendar sub package (boo#902657)
* Sun Nov  9 2014 tittiatcoke@gmail.com
- Update to 4.11.14
  * KDE 4.14.3 SC Bugfix Release
  * See http://www.kde.org/announcements/announce-4.14.3.php
* Sun Oct 12 2014 tittiatcoke@gmail.com
- Update to 4.11.13
  * KDE 4.14.2 SC Bugfix Release
  * See http://www.kde.org/announcements/announce-4.14.2.php
* Sun Sep 28 2014 ftake@geeko.jp
- Fix bnc#768896
  * Allow to revert fontconfig settings to the distribution default
  * Prevent kcm_fonts from saving inappropriate values
    when kcm_fonts is opened
  * Add kcm-fix-105797-fontconfig.patch
* Mon Sep 22 2014 tittiatcoke@gmail.com
- Make kactivities4 a hard requirement (bnc#896660)
* Sat Sep 13 2014 tittiatcoke@gmail.com
- Update to 4.11.12
  * KDE 4.14.1 SC Bugfix Release
  * See http://www.kde.org/announcements/announce-4.14.1.php
- Drop upstream patch
  changeset_re8241313fc979aefafc8c2a0207570d6394f1580.diff
* Wed Sep  3 2014 hrvoje.senjan@gmail.com
- Create new addons subpackage: split out systemsettings and addons
  for co-instability with Plasma5 and to maintain the ability to
  maintain settings for kdelibs4 based applications
- Move all oxygen components in liboxygenstyle subpackage
- Add libs subpackage to baselibs (needed for liboxygenstyle)
- Harden interdependancies of some packages
* Tue Aug 19 2014 hrvoje.senjan@gmail.com
- Package gui_platform plugins within libs subpackage: the plugin
  is not shared library but is important for some core features
  of KDE applications (correct filedialog, style loading, etc)
* Mon Aug 18 2014 jslaby@suse.com
- changeset_re8241313fc979aefafc8c2a0207570d6394f1580.diff: Require
  strict binding for intel driver (bnc#892305)
* Sat Jul 12 2014 cgiboudeaux@gmx.com
- Update to 4.11.11
  * KDE 4.13.3  bug fix release
  * See http://www.kde.org/announcements/announce-4.13.3.php
* Fri Jul 11 2014 cgiboudeaux@gmx.com
- Fix a couple rpmlint warnings.
* Thu Jun 12 2014 hrvoje.senjan@gmail.com
- Create libs subpackage, which contains all shared libraries comming
  from kde-workspace, to allow more flexibility in what applications
  would be removed if kdebase4-workspace is removed
* Sun Jun  8 2014 tittiatcoke@gmail.com
- Update to 4.11.10
  * KDE 4.13.2  bug fix release
  * See http://www.kde.org/announcements/announce-4.13.2.php
- Drop fix-crash-when-DesktopNames-isnt-set.patch due to upstream
  inclusion
* Fri Jun  6 2014 hrvoje.senjan@gmail.com
- Create new libkworkspace4 subpackage: this library is used for
  other external packages, such as kdm, apper, homerun, etc.
  This prevents removal of those packages in case user wants to
  remove kdebase4-workspace package
- Move all the oxygen parts in liboxygenstyle subpackage
* Tue May 27 2014 hrvoje.senjan@gmail.com
- Build with pkgconfig(libudev), not pkgconfig(udev)
* Wed May 21 2014 tittiatcoke@gmail.com
- Adjust some defaults back to the original ones from upstream.
  This would ensure that with a default setup the user is able
  to shutdown the system. Another step to remove dependencies on
  the openSUSE sysconfig values, which is something that our
  users are not happy with
* Tue May 20 2014 tittiatcoke@gmail.com
- Restore reading AutoLogin from the openSUSE sysconfig values
  again. This breaks otherwise openqa
* Sat May 10 2014 hrvoje.senjan@gmail.com
- Install DBus interface files with devel subpackage, they are used
  for development purposes only
* Tue May  6 2014 tittiatcoke@gmail.com
- Further reduce the number of KDM settings that are taken from
  the values in sysconfig. We try to be on-par with GDM
  (bnc#860507)
* Fri May  2 2014 hrvoje.senjan@gmail.com
- Added fix-crash-when-DesktopNames-isnt-set.patch, kde#334159
* Tue Apr 29 2014 hrvoje.senjan@gmail.com
- Split out default cursors into separate oxygen-cursors4 package,
  for allowing users they choose between cursors coming from
  kdebase4-workspace and future Plasma Next releses
* Fri Apr 25 2014 tittiatcoke@gmail.com
- Update to 4.11.9
  * Bugfix release
- Remove upstreamed patches
  - screenlocker-always-show-password-dialog-when-needed.patch
  - screenlocker-dont-leak-screensaver-processes.patch
  - kdm-fix-resumption-from-console-mode.patch
* Thu Apr 10 2014 wbauer@tmo.at
- Added kdm-fix-resumption-from-console-mode.patch:
  * fix resumption from console mode when monotonic clock is in use
    (kde#312947, bnc#756198)
- Added screenlocker-always-show-password-dialog-when-needed.patch:
  * password input dialog was not shown under certain circumstances
    (kde#327947, kde#329076, bnc#864305)
- Added screenlocker-dont-leak-screensaver-processes.patch:
  * screensaver processes might keep running in background when
    unlocking the screen (kde#224200, bnc#809835)
* Sat Mar 29 2014 tittiatcoke@gmail.com
- Update to 4.11.8
  * KDE 4.12.4  release
  * See http://www.kde.org/announcements/announce-4.12.4.php
- Drop upstreamed patches:
  - 0001-Add-the-full-name-of-completion-matches-to-history.patch
  - 0002-Move-focus-to-search-field-upon-typing-from-result-l.patch
  - 0003-Save-current-dialog-size-on-manual-resize.patch
* Sun Mar 16 2014 stefan.bruens@rwth-aachen.de
- added patch kde-workspace-4.11.0-kdm-logind-multiseat.patch for
  servers without VT, i.e. multiseat with sharevts
- add support for dynamic multiseat
* Fri Mar 14 2014 hrvoje.senjan@gmail.com
- Added patches from master (due to upstream 'LTS' policy not applied
  to 4.11 branch)
  0001-Add-the-full-name-of-completion-matches-to-history.patch and
  0002-Move-focus-to-search-field-upon-typing-from-result-l.patch and
  0003-Save-current-dialog-size-on-manual-resize.patch
* Fri Mar  7 2014 tittiatcoke@gmail.com
- Update to 4.11.7
  * KDE 4.13 Beta1  release
  * See http://www.kde.org/announcements/announce-4.13-beta1.php
- Drop upstream patches:
  * 0001-Explicitly-request-a-Window-drawable.patch
  * 0004-align-zoomed-cursor-to-hotspot.patch
  * 0005-be-more-aggressive-about-exiting-zoom-effect.patch
  * 0006-spatial-present-windows-zoom-calculation.patch
  * 0007-fix-frontbuffer-copying-swap-preference.patch
  * 0008-fix-sendToScreen-for-QuickTiled-windows.patch
  * 0009-reset-desktopChangedWhileRotating-on-activation.patch
  * 0010-ensure-to-show-clients-that-need-sessionInteract.patch
  * 0011-fix-off-by-1-on-multiscreen-toppanel-strutting.patch
  * 0012-Perform-the-systemd-version-evaluation-through-a-reg.patch
- Add patch  remove_strigi.patch to remove the dependency on strigi
- Dropped 12.2 related lines in the spec-file as well the
  rcksysguard, as that this is since 12.3 a systemd service.
* Thu Feb 27 2014 hrvoje.senjan@gmail.com
- Added various bugfix patches from upstream 4.11 branch:
  * 0001-Explicitly-request-a-Window-drawable.patch
  * 0004-align-zoomed-cursor-to-hotspot.patch
  * 0005-be-more-aggressive-about-exiting-zoom-effect.patch
  * 0006-spatial-present-windows-zoom-calculation.patch
  * 0007-fix-frontbuffer-copying-swap-preference.patch
  * 0008-fix-sendToScreen-for-QuickTiled-windows.patch
  * 0009-reset-desktopChangedWhileRotating-on-activation.patch
  * 0010-ensure-to-show-clients-that-need-sessionInteract.patch
  * 0011-fix-off-by-1-on-multiscreen-toppanel-strutting.patch
  * 0012-Perform-the-systemd-version-evaluation-through-a-reg.patch
* Sat Feb  1 2014 tittiatcoke@gmail.com
- Update to 4.11.6
  * KDE 4.12.2 release
  * See http://www.kde.org/announcements/announce-4.12.2.php
- Drop upstreamed patch
  * screenlocker-fix-mousecursor-blanking.diff
* Sun Jan 19 2014 dap.darkness@gmail.com
- plasma-calendar recommends akonadi-runtime instead of kde4_akonadi_requires
- No supplement of packageand(akonadi-runtime:kdebase4-workspace)
  [the same as has already applied at Sun Jul  1 20:26:42 UTC 2012]
* Mon Jan 13 2014 speilicke@suse.com
- Nothing requires kactivities4, recommending it is sufficient
* Wed Jan  8 2014 wbauer@tmo.at
- Added screenlocker-fix-mousecursor-blanking.diff:
  Allow Screensavers to blank the mouse cursor again
  (kde#311571, kde#316459)
* Sat Jan  4 2014 tittiatcoke@gmail.com
- Update to 4.11.5
  * KDE 4.11.5 maintenance release
  * See http://www.kde.org/announcements/announce-4.11.5.php
- Drop kscreensaver-disable-sessionmanagement.diff as it was
  included upstream
* Wed Dec 18 2013 hrvoje.senjan@gmail.com
- Anchor external (Build)Requires to %%{_kde_platform_version} as
  once 4.11.5 is out, we would have issues building e.g.
  kde-workspace 4.11.6
* Sat Dec  7 2013 hrvoje.senjan@gmail.com
- Update to 4.11.4
  * KDE 4.11.4 bugfix release
  * See http://www.kde.org/announcements/announce-4.11.4.php
- Drop 0001-introduce-a-locked-property-for-the-qml-lock-screen.patch
  and adjust-to-upower-0.99.patch, they are included in this release
* Fri Nov 22 2013 hrvoje.senjan@gmail.com
- Disable previous patch, due to bad side-effects (kde#327947)
* Fri Nov 22 2013 hrvoje.senjan@gmail.com
- Added 0001-introduce-a-locked-property-for-the-qml-lock-screen.patch
  from upstream, for resolving potential security risk where the
  screenlocker would show it's locked, but infact isn't
  (kde#315442, bnc#802959)
* Sun Nov 10 2013 hrvoje.senjan@gmail.com
- Due to upstream chages in kde-workspace release policy (only 4.11.x
  bugfixes) require kdeartwork4, kdebase4-wallpaper-default and
  python-kde4 equal or greater than kde-workspace version
- Added adjust-to-upower-0.99.patch which ports Powerdevil to new
  UPower API/ABI/DBus interface
* Sat Nov  2 2013 tittiatcoke@gmail.com
- Update to 4.11.3
  * KDE 4.11.3 bugfix release
  * See http://www.kde.org/announcements/announce-4.11.3.php
- Drop helper_actions_syspath.patch, and create rpmlintrc file during
  build phase for older openSUSE versions
* Sat Nov  2 2013 tittiatcoke@gmail.com
- Drop patches due to upstream inclusion:
  * 0001-QDeclarativeRepeaterCrashFix_kde#311871.patch
  * fix-click-on-trash-plasmoid.diff
* Sun Oct 27 2013 hrvoje.senjan@gmail.com
- Added 0001-QDeclarativeRepeaterCrashFix_kde#311871.patch, fixes
  annoying plasma crash when notifications would get shown,
  (kde#311871, bnc#812536, bnc#808656)
* Mon Oct 14 2013 wbauer@tmo.at
- Adjust kdm-sysconfig-values.diff to set default boot loader to
  "Grub2" in kdm's kcm as well (bnc#845809)
* Fri Oct 11 2013 hrvoje.senjan@gmail.com
- Adjust kdm-sysconfig-values.diff so it doesn't dictates AllowNullPasswd
  option (bnc#833634)
- Make main package Recommends kde-gtk-config (bnc#845592)
* Mon Oct  7 2013 wbauer@tmo.at
- Added fix-click-on-trash-plasmoid.diff: Fix click on trashcan
  plasmoid when on desktop and widgets are unlocked (kde#325330)
* Sat Sep 28 2013 tittiatcoke@gmail.com
- Update to 4.11.2
  * KDE 4.11.2 bugfix release
  * See http://www.kde.org/announcements/announce-4.11.2.php
- Dropped patches due to upstream inclusion:
    0001-make-it-possible-to-match-applications-with-fewer-ke.patch
    0002-Add-the-full-name-of-completion-matches-to-history.patch
    0003-Delay-KDE-class-initialization-to-main-loop.patch
    changeset_re1a590badee13b862c5393f45ea59ecad98a7267.diff
    kwin-fix-crash.diff
* Thu Sep 26 2013 jslaby@suse.com
- Added changeset_re1a590badee13b862c5393f45ea59ecad9: Don't propagate
  drops to the containment while animating (kde#324391)
* Tue Sep 17 2013 alarrosa@suse.com
- Added kwin-fix-crash.diff:
  Fixes a crash when trying to use GLX, which happened when starting
  KDE inside qemu (bnc#840490)
* Tue Sep 10 2013 wbauer@tmo.at
- Added kscreensaver-disable-sessionmanagement.diff:
  disable session management for screensavers
  prevents screensaver windows popping up at login (kde#314859, bnc#809835)
* Mon Sep  9 2013 hrvoje.senjan@gmail.com
- Added 0003-Delay-KDE-class-initialization-to-main-loop.patch from
  upstream 4.11 branch for resolving kde#324574 - 'Application specific
  icon now doesn't work' bug
* Sat Sep  7 2013 hrvoje.senjan@gmail.com
- Added two patches from upstream master branch, for improving krunner
  usability:
  0001-make-it-possible-to-match-applications-with-fewer-ke.patch and
  0002-Add-the-full-name-of-completion-matches-to-history.patch
* Sat Sep  7 2013 tittiatcoke@gmail.com
- Reduce the amount of KDM settings in sysconfig/displaymanager to
  purely autologin. This enables that KDM can be configured again
  through the normal KDE systemsettings module. (bnc#267903)
* Thu Sep  5 2013 wbauer@tmo.at
- Changed plasma-kickoff-newly-collapsing.diff:
  * don't remove upstream's duplicates handling code anymore since
    kde3-applications.diff is dropped now from kdelibs4
  * don't append " (category)" to collapsed entries' names anymore,
    not necessary because duplicates are filtered out now anyway
  * simplify and reformat patch
* Sun Sep  1 2013 amolagodbole@gmail.com
- Added add-calculator-hotkey.patch, which adds a default hotkey to
  launch KCalc on pressing the Calculator button (bnc#726550)
* Sun Sep  1 2013 tittiatcoke@gmail.com
- Update to 4.11.1
  * KDE 4.11.1 bugfix release
  * See http://www.kde.org/announcements/announce-4.11.1.php
* Sun Sep  1 2013 tittiatcoke@gmail.com
- Drop upstream patches as preparation for the 4.11.1 update
  * 0001-Add-back-window-ids-to-the-drag-data-payload.patch
  * 0002-Fix-rare-race-condition-crash.patch
  * 0003-make-stacking_order-exclusive-during-shutdown.patch
  * 0004-Don-t-attempt-to-publish-geometry-for-launcher-items.patch
  * 0005-More-sanity-checking.patch
  * 0006-c-cannot-invoke-other-constructors.patch
  * 0007-print-active-screen-strategy-blocking-for-retrace.patch
  * 0008-align-GUI-object-name-to-kcfg-name.patch
* Sun Aug 25 2013 hrvoje.senjan@gmail.com
- Added 2 patches from upstream instead of the previous workaround,
  and aditional 3 for various KWin issues:
  0004-Don-t-attempt-to-publish-geometry-for-launcher-items.patch
  0005-More-sanity-checking.patch
  0006-c-cannot-invoke-other-constructors.patch
  0007-print-active-screen-strategy-blocking-for-retrace.patch
  0008-align-GUI-object-name-to-kcfg-name.patch
* Sun Aug 25 2013 hrvoje.senjan@gmail.com
- Added workaround for kde#322283, bnc#829298: execute plasma-desktop
  with LANG enviroment variable
* Sat Aug 17 2013 hrvoje.senjan@gmail.com
- Added three patches from upstream 4.11 branch:
  0001-Add-back-window-ids-to-the-drag-data-payload.patch
  this e.g. makes dropping tasks on the pager work again (kde#322567),
  0002-Fix-rare-race-condition-crash.patch (kde#323496) and
  0003-make-stacking_order-exclusive-during-shutdown.patch (kde#323383)
* Fri Aug 16 2013 schwab@linux-m68k.org
- kdm-backend-session.patch: fix type mismatch in resource handling
* Thu Aug 15 2013 hrvoje.senjan@gmail.com
- Activate building of KWin's Wayland backend
- Move akonadi dataengine to calendar subpackage, so
  %%akonadi_runtime_requires can be also moved there
- Adjust sysconfig.displaymanager-kdm for current default upstream
  theme
- Drop xcb-util-wm-devel BuildRequires as per upstream change
  between 4.10.90 and 4.10.95
- Apply helper_actions_syspath.patch only on openSUSE versions lower
  than 13.1, as bnc#825256 is resolved
* Thu Aug  8 2013 tittiatcoke@gmail.com
- Update to 4.11.0
  * KDE 4.11 Final release
  * See http://www.kde.org/announcements/4.11/
- Dropped upstream patches:
  0001-notify-the-client-when-a-notification-is-dismissed-b.patch
  0002-Enable-LayoutMirroring.patch
  0003-Proper-appearance-and-geometry-for-launcher-items.patch
  0004-Hide-unimplemented-manual-grouping-option.patch
  0005-Try-to-make-sure-the-group-dialog-stays-within-a-san.patch
  0006-Make-sure-tasks-are-layouted-before-they-are-shown.patch
  0007-Fix-bidi-layout-support.patch
  0008-Restore-correct-index-when-turning-a-task-back-into-.patch
* Sat Jul 27 2013 hrvoje.senjan@gmail.com
- Added patches from upstream KDE/4.11 branch for resolving remaining
  QML task manager regressions:
  0001-notify-the-client-when-a-notification-is-dismissed-b.patch
  0002-Enable-LayoutMirroring.patch
  0003-Proper-appearance-and-geometry-for-launcher-items.patch
  0004-Hide-unimplemented-manual-grouping-option.patch
  0005-Try-to-make-sure-the-group-dialog-stays-within-a-san.patch
  0006-Make-sure-tasks-are-layouted-before-they-are-shown.patch
  0007-Fix-bidi-layout-support.patch
  0008-Restore-correct-index-when-turning-a-task-back-into-.patch
* Thu Jul 25 2013 hrvoje.senjan@gmail.com
- Update to 4.10.97
  * KDE 4.11 RC 2 release
  * See http://www.kde.org/announcements/announce-4.11-rc2.php
* Wed Jul 24 2013 stefan.bruens@rwth-aachen.de
- fix plymouth patch breaking server startup (bnc#809806 c51)
* Tue Jul 16 2013 stefan.bruens@rwth-aachen.de
- update kdm_plymouth patch to make it work with multiple static
  X servers (bnc#809806)
* Tue Jul 16 2013 tittiatcoke@gmail.com
- Based on the upstream decision, drop krandr as a requirement for
  kdebase4-workspace and replace it with kscreen. Kscreen is the
  new screen management tool.
* Mon Jul 15 2013 cgiboudeaux@gmx.com
- Update to 4.10.95
  * KDE 4.11 RC 1 release
  * See http://www.kde.org/announcements/announce-4.11-rc1.php
* Sun Jul 14 2013 dmueller@suse.com
- add krandr requires to kdebase4-workspace (used by startkde)
* Wed Jul  3 2013 hrvoje.senjan@gmail.com
- Added helper_actions_syspath.patch, which disables
  org.kde.powerdevil.backlighthelper.syspath policy, until bnc#825256
  gets resolved
- Removed rpmlintrc file
* Tue Jul  2 2013 tittiatcoke@gmail.com
- Use the new variable _kde_branding_version for the version of the
  branding packages/requires.
* Thu Jun 27 2013 tittiatcoke@gmail.com
- Update to 4.10.90
  * KDE 4.11 Beta 2 release
  * See http://www.kde.org/announcements/announce-4.11-beta2.php
- Dropped enable-color-correction-only-after-contacting-kolormanager.diff
  and pager diff, patches included in this release
* Sun Jun 23 2013 hrvoje.senjan@gmail.com
- Added enable-color-correction-only-after-contacting-kolormanager.diff
  fixes kde#321217
- Removed NetworkManager-devel from buildrequires, not needed anymore
* Thu Jun 20 2013 werner@suse.de
- Make plymouth patch smart that is do only force standard X server
  on the active console but not any other (bnc#809806)
* Mon Jun 17 2013 hrvoje.senjan@gmail.com
- Split out krandr modules and apps into separate package, so it
  can be obsoleted by KScreen
- Make main package recommends kscreen package
* Fri Jun 14 2013 wbauer@tmo.at
- Changed plasma-kickoff-newly-collapsing.diff:
  * Use the same sorting algorithm as the upstream code (respects
    the current locale, f.e.)
  * don't always ignore separators
  * Show collapsed entries as "name (category)" instead of
    "category (name)"
  * cleanup/remove some unneeded/unused stuff
* Thu Jun 13 2013 tittiatcoke@gmail.com
- Update to 4.10.80
  * KDE 4.11 Beta 1 release
  * See http://www.kde.org/announcements/announce-4.11-beta1.php
- Dropped upstreamed patches: kdm-fix-greeteruid.patch,
  systemd-session-management-support-in-the-workspace.patch,
  dont-install-solid-netbackends.diff and storage.diff
* Sat Jun  1 2013 tittiatcoke@gmail.com
- Update to 4.10.4
  * Bugfix release
  * See http://www.kde.org/announcements/announce-4.10.4.php
  * resolves bnc#8122760
* Sat May 18 2013 hrvoje.senjan@gmail.com
- Remove polkit-kde-kcmmodules-1 from Requires, as the package is
  broken - it overwrites rules shipped by other packages (kde#308934),
  and confuses users that it does something it doesn't (bnc#814763)
* Wed May 15 2013 mhrusecky@suse.com
- kwin provides kde4-kwin for backward compatibility
* Mon May 13 2013 tittiatcoke@gmail.com
- Change the default path for the AuthFiles of KDM. Fixes
  bnc#818792 in a proper way.
* Tue May  7 2013 tittiatcoke@gmail.com
- Add patch kdm-fix-greeteruid.patch from upstream to have the
  proper greeterUID created.
* Sat May  4 2013 tittiatcoke@gmail.com
- Update to 4.10.3
  * Bugfix release
  * See http://www.kde.org/announcements/announce-4.10.3.php
  * resolves bnc#818500
- Dropped fix-plasma-theme-workaround-tabbox.patch, it's included in
  this release
* Fri Apr 26 2013 hrvoje.senjan@gmail.com
- Remove plasma-notifications-kill-timer.diff, that was fix for
  kde#230740, but it is commited upstream 3 years ago
- Remove unused patches: kwin-suse.diff, kdm-audit-log.diff,
  systemsettings-root-kcm.diff, pam-translate.diff and
  kdm-suspend-hal.diff (which used HAL, but we migrated away from
  it long ago)
- Group patches wheter they are for KDM or Workspace components
- Remove checks and obsoletes/provides for no longer supported versions
- Fix rpmlint warnings: devel files shipping in the main package and
  kdm missing logrotate dependency
- Remove not needed kdesud %%verify checks
- Added %%kde4_runtime_requires to ksysguard and plasma-calendar packages
- Annotate existing patches where possible
* Wed Apr 17 2013 hrvoje.senjan@gmail.com
- Replace workspace_systemd_initial_support.patch with upstream
  systemd-session-management-support-in-the-workspace.patch
  This also makes build flag DKWORKSPACE_USE_SYSTEMD obsolete
- Require kdebase4-artwork and kdebas4-wallpaper-default for upstream
  branding, otherwise those packages provide the same files
* Wed Apr 10 2013 mmeister@suse.com
- Added url as source.
  Please see http://en.opensuse.org/SourceUrls
* Mon Apr  1 2013 tittiatcoke@gmail.com
- Update to 4.10.2
  * Bugfixes
- Drop validate_systemd_version_for_upower.diff, it is pushed upstream
* Thu Mar 21 2013 crrodriguez@opensuse.org
- Add a native systemd unit for ksysguardd and exclude
  the old init scripts for newer distros.
* Thu Mar  7 2013 tittiatcoke@gmail.com
- Add patch validate_systemd_version_for_upower.diff. this patch
  checks if the version of systemd supports suspend/hibernate and
  resolves the current issue on openSUSE 12.2
* Mon Mar  4 2013 wbauer@tmo.at
- changed plasma-kickoff-newly-collapsing.diff:
  * use KService ptr instead of name for specialTitle map, so it
    still works correctly when there are entries with equal names
    (bnc#807301)
* Sat Mar  2 2013 tittiatcoke@gmail.com
- Update to 4.10.1
  * Contains bug fixes. See http://www.kde.org/announcements/
  for more information
- Drop plasma_expire_suse_paste.diff, powerdevil-logind.patch and
  respect_screenlock_settings.diff, all applied upstream
* Thu Feb 28 2013 wbauer@tmo.at
- Change default Bootmanager to "Grub2" in kdmrc (bnc#788867)
* Thu Feb 28 2013 crrodriguez@opensuse.org
- Add powerdevil-logind.patch, allows powerdevil to
  interact properly with systemd-logind
  (https://git.reviewboard.kde.org/r/108407)
* Thu Feb 21 2013 hrvoje.senjan@gmail.com
- Added GLU buildrequires, needed for KInfoCenter
* Wed Feb 13 2013 hrvoje.senjan@gmail.com
- Added fix-plasma-theme-workaround-tabbox.patch, fixes kde#315064
* Tue Feb 12 2013 ctrippe@opensuse.org
- Added plasma_expire_suse_paste.diff (fixes bnc#803384)
* Mon Feb 11 2013 hrvoje.senjan@gmail.com
- Added pager.diff, fixes bnc#799875
* Mon Feb 11 2013 wbauer@tmo.at
- changed plasma-kickoff-newly-collapsing.diff:
  * sort entries by genericName if "Show applications by name"
    is switched off (bnc#803179)
* Mon Feb 11 2013 tittiatcoke@gmail.com
- Added upstream patch respect_screenlock_settings.diff. This would
  allow again the old behavior of the screensaver and the new
  screenlocker respects now all the settings (e.g. no password,
  etc) (bnc#802704)
* Mon Feb 11 2013 wstephenson@suse.com
- Remove the kio-mtp package, moved to KDE4-DESKTOP pattern instead
* Sat Feb  9 2013 tittiatcoke@gmail.com
- Recommend the kio-mtp package so that solid can communicate
  with Android phones (bnc#765051)
* Thu Feb  7 2013 tittiatcoke@gmail.com
- Remove patch 0001-Tweak-the-locker-wallpaper.patch. The patch
  causes strange borders when the screen has a different
  screen ratio than the wallpaper.
* Thu Feb  7 2013 wbauer@tmo.at
- changed plasma-kickoff-newly-collapsing.diff:
  * add ":F" to the sortOrder list if it isn't included to make sure
    collapsed entries are really shown (bnc#356553)
* Thu Feb  7 2013 tittiatcoke@gmail.com
- BuildRequire kdebase4-wallpapers so that the 4.10 default wallpaper
  can be provided with the branding-upstream package
- BuildRequire kdebase4-artwork so that the 4.10 default ksplash
  theme can be provided with the branding-upstream package
* Mon Feb  4 2013 hrvoje.senjan@gmail.com
- Add 0001-Tweak-the-locker-wallpaper.patch, to fix locker's
  wallpaper rendering
* Thu Jan 31 2013 tittiatcoke@gmail.com
- Update to 4.10.0
  * This is the final release for 4.10. Contains bugfixes
* Thu Jan 31 2013 wbauer@tmo.at
- changed plasma-kickoff-newly-collapsing.diff:
  * in config dialog: connect added options to settingsModified()
    slot so that "Apply" button gets activated when they are changed
    by the user (bnc#801416)
* Fri Jan 25 2013 ctrippe@opensuse.org
- changed kdm-cope-with-new-grub.diff
  * kdm: don't even look for grub-set-default, we won't need it
    (bnc#771545)
* Thu Jan 24 2013 ctrippe@opensuse.org
- changed plasma-kickoff-newly-collapsing.diff:
  * display program icon instead of submenu icon when using reduced
    menu depth (bnc#641916)
* Tue Jan 22 2013 wbauer@tmo.at
- changed plasma-kickoff-newly-collapsing.diff:
  * don't set name to null if it is equal to genericName or
    genericName is empty. Fixes bnc#725829
* Mon Jan 21 2013 alinm.elena@gmail.com
- updated storage.diff to the one that is in review board
* Sun Jan 20 2013 ctrippe@opensuse.org
- Update patch plasma-branding-defaults-applets.diff to add
  kinfocenter to kickoff in the Computer tab
* Sun Jan 20 2013 alinm.elena@gmail.com
- Add unique names for partitions in kinfocenter (storage.diff)
* Fri Jan 18 2013 wstephenson@suse.com
- Add krunner-no-italics.diff to make krunner hits pretty  (kde#307344)
* Thu Jan 17 2013 tittiatcoke@gmail.com
- Update to 4.9.98
  * This is the third RC release for 4.10. Contains bugfixes
- Dropped krunner-no-crash.diff, included upstream
* Tue Jan 15 2013 coolo@suse.com
- do not reqiure openSUSE specifics, that's what branding packages
  are for
* Mon Jan 14 2013 tittiatcoke@gmail.com
- Delete only the incorrect directory
  /usr/share/kde4/apps/ksmserver/ksmserver.notifyrc/ and don't
  touch the file.
* Sun Jan 13 2013 tittiatcoke@gmail.com
- Added patch opensuse-kinfocenter.diff to have some additional
  openSUSE information in kinfocenter. Kinfocenter will be the
  replacement for kio_sysinfo.
- Added Require for openSUSE-release as that kinfocenter uses the
  info from here.
* Sun Jan 13 2013 ctrippe@opensuse.org
- Update patch plasma-branding-defaults-applets.diff to remove
  kio_sysinfo from kickoff
* Tue Jan  8 2013 alinm.elena@gmail.com
- added patch krunner-no-crash.diff to fix a possible krunner crash
* Mon Jan  7 2013 wbauer@tmo.at
- Fix typo in kdm postinstall script
* Sun Jan  6 2013 tittiatcoke@gmail.com
- Updated plymouth patch with the correct path (/usr/bin/plymouth)
* Thu Jan  3 2013 tittiatcoke@gmail.com
- Update to 4.9.97
  * This is the second RC release for 4.10. Contains bugfixes
* Thu Dec 27 2012 hrvoje.senjan@gmail.com
- Clean the BuildRequirements:
  * audit-devel, bluez-devel, libsmbclient-devel are not required,
  and libdbusmenu-qt-devel was listed twice
- Remove obsolete -DKDE4_KCHECKPASS_PAM_SERVICE flag
* Wed Dec 19 2012 tittiatcoke@gmail.com
- Update to 4.9.95
  * This is the first RC release for 4.10. Contains bugfixes
* Sat Dec  1 2012 tittiatcoke@gmail.com
- Update to 4.9.90
  * This is the second Beta release for 4.10. Contains bugfixes
* Sun Nov 25 2012 tittiatcoke@gmail.com
- Drop patch 4_7_branch.diff, which is not used at all
* Sat Nov 24 2012 tittiatcoke@gmail.com
- Update to 4.9.80
  * see http://www.kde.org/announcements/announce-4.10-beta1.php
  * New qml based screen locker
  * Kwin fixes (bko#308990, bko#102607, bko#296773, bko#266596,
    bko#308994, bko#308995, bko#309006, bko#305875, bko#179077,
    bko#183996, bko#244439, bko#297634, bko#297637, bko#301103,
    bko#303093, bko#303314, bko#303579, bko#305738, bko#306384,
    bko#306436, bko#307609, bko#307866, bko#269207, bko#299277,
    bko#301327, bko#303090, bko#303756, bko#303810, bko#305832)
  * Notifications applet was ported to QML
  * System tray with interface in QML
  * Overhaul powerdevil notifications and initial implementation
    of upower/systemd support
  * Keyboard layout preview in Systemsettings
* Fri Nov 16 2012 tittiatcoke@gmail.com
- Also make sure that KDM doesn't require ConsoleKit anymore.
* Thu Nov 15 2012 tittiatcoke@gmail.com
- Activate systemd support for Factory only. This disables
  ConsoleKit support !!
* Fri Nov  2 2012 tittiatcoke@gmail.com
- Update to 4.9.3
  * see http://kde.org/announcements/announce-4.9.3.php for details
- Removed upstream patch (upstream-python-applets.diff) as it
  is now included upstream.
* Tue Oct  9 2012 ctrippe@opensuse.org
- require xdm as the patch kdm-sysconfig-values.diff requires
  /var/lib/xdm/authdir/authfiles at runtime (bnc#784212)
* Mon Oct  1 2012 belphegor@belbel.or.jp
- removed kde3 parts from /usr/lib/X11/displaymanagers/kdm
  (bnc#775548)
* Mon Oct  1 2012 tittiatcoke@gmail.com
- Combine python-kdebase4 and kdebase4-workspace in a single
  spec-file. Python-kdebase4 no longer needs python-devel files to
  build.
* Sat Sep 29 2012 tittiatcoke@gmail.com
- Update to 4.9.2
  * see http://kde.org/announcements/announce-4.9.2.php for details
* Sat Sep 15 2012 jslaby@suse.com
- add kdm logrotate script (bnc#552449)
* Wed Sep  5 2012 dmueller@suse.com
- update to 4.9.1
  * see http://kde.org/announcements/4.9.1/ for details
- require windowmanager and xmessage,xprop, as they're needed for starting a session
* Mon Jul 30 2012 dmueller@suse.com
- update to 4.8.5
  * see http://kde.org/announcements/changelogs/changelog4_8_4to4_8_5.php for details
- refresh patches
* Mon Jul 30 2012 mlin@suse.com
- Apply to upstream to fix deletion of preferred launchers (bnc#757370, kde#278724)
* Sun Jul  1 2012 dap.darkness@gmail.com
- plasma-calendar recommends akonadi-runtime instead of kde4_akonadi_requires
- No supplement of packageand(akonadi-runtime:kdebase4-workspace)
* Fri Jun  1 2012 dmueller@suse.com
- update to 4.8.4
  * see http://kde.org/announcements/changelogs/changelog4_8_3to4_8_4.php for details
* Tue May  1 2012 anixx@opensuse.org
- remove "obsoletes" and "provides" for kdebase3-ksysguardd as I completely
  separated the two and removed the conflict: both KDE3 and KDE4 versions
  can be installed in parallel now
* Sun Apr 29 2012 dmueller@suse.com
- update to 4.8.3
  * see http://kde.org/announcements/changelogs/changelog4_8_2to4_8_3.php for details
* Sat Apr 14 2012 dmueller@suse.com
- remove dependency on google-gadgets
* Tue Apr 10 2012 ctrippe@opensuse.org
- Require desktop-data-openSUSE as this is needed for the KDE menu
  (bnc#754104)
* Mon Apr  2 2012 wstephenson@suse.com
- Add patch for kde#297272 - KWin does not repaint window
  shadow regions after closing window
* Sat Mar 31 2012 ctrippe@opensuse.org
- Change the entry for sysinfo in kickoff to "My Computer" to make
  it consistent with the actual window (bnc#626886)
* Sat Mar 31 2012 wstephenson@suse.com
- Add xz to BuildRequires
- Remove kdepimlibs4 requirement from base package because this has
  now been moved into the subpackages that have a real requirement.
* Thu Mar 29 2012 dmueller@suse.de
- update to 4.8.2
  * see http://kde.org/announcements/changelogs/changelog4_8_1to4_8_2.php for details
* Thu Mar 29 2012 wstephenson@suse.com
- Stop installing redundant Network Management backends
* Tue Mar 20 2012 tittiatcoke@gmail.com
- Added patch to support GRUB2
- Added patch to resolve reboot/shutdown issue when using systemd
  and KDM
- Added patch to have initial support within kdebase4-workspace for
  shutdown/reboot through systemd. Not yet Activated !!
- Included patch from Rober Milasan to set the correct default
  homepage for the openSUSE branding
* Fri Mar  2 2012 dmueller@suse.de
- update to 4.8.1
  * see http://kde.org/announcements/changelogs/changelog4_8_0to4_8_1.php for details
* Mon Feb 27 2012 dmueller@suse.de
- require the right version of kactivities4 to avoid crashes
* Wed Jan 18 2012 dmueller@suse.de
- update to 4.8.0
  * first stable release of KDE 4.8 (only critical fixes over 4.7.98)
  * see http://kde.org/announcements/4.8/ for details
* Tue Jan 10 2012 dmueller@suse.de
- update to 4.7.98
  * RC2+ milestone release of KDE 4.8
  * see http://kde.org/announcements/4.8/ for details
* Mon Dec 12 2011 saschpe@suse.de
- Use supplements packageand instead of recommends
- Added split provides
* Wed Dec  7 2011 saschpe@suse.de
- New subpackages plasma-engine-akonadi and plasma-calendar:
  * Removed %%kde4_akonadi_requires from base package, otherwise
    half of KDE depends on akonadi-runtime.
  * Both are recommended by base package
* Fri Dec  2 2011 dmueller@suse.de
- update to 4.7.4
  * see http://kde.org/announcements/changelogs/changelog4_7_3to4_7_4.php for details
* Mon Nov 28 2011 idoenmez@suse.de
- Fix duplicated files
* Sat Nov 26 2011 ctrippe@opensuse.org
- show window size in characters if resizing terminal (bnc#703594)
* Thu Nov 24 2011 jslaby@suse.de
- show window size in characters if resizing terminal (bnc#703594)
* Tue Nov 22 2011 wstephenson@sue.com
- Fix slow KDE logout/shutdown dialog apearance
  (bnc#729823,kde#265405)
* Mon Nov 21 2011 coolo@suse.com
- revert most of the branding commit
* Sun Nov 20 2011 toddrme2178@gmail.com
- Fixed self-obsoletes (fix for RPMLINT warning)
- Added %%kde4_runtime_requires (fix for RPMLINT warning)
- Added %%kde4_akonadi_requires (fix for RPMLINT warning)
- Added %%kde4_pimlibs_requires (fix for RPMLINT warning)
- Enabled -fPIE building (fix for RPMLINT warning)
- Added permission prereq (fix for RPMLINT warning)
- Added %%set_permissions macros (fix for RPMLINT warning)
- Fixed permissions for kcheckpass (fix for RPMLINT warning)
- Fixed devel package group (fix for RPMLINT warning)
- Added %%config tag (fix for RPMLINT warning)
- Cleaned up spec file formatting
* Fri Nov 18 2011 alinm.elena@gmail.com
- bumped the branding version to reflect 12.1 and factory
- fixed kwin dependency on the opensuse branding
- reworked the logic for selecting the version string
* Thu Nov 17 2011 idonmez@suse.com
- Unbreak signalling remaining time on the battery
* Mon Nov 14 2011 renda.krell@gmail.com
- Add changeset_r639155a5493a28ca9460d60fa0c078ec65c3bb96.diff to fix bko#272495
* Wed Nov  9 2011 javier@opensuse.org
- Add plasma-crash-on-logout.diff to fix bko#275286
* Thu Nov  3 2011 mlin@suse.com
- Add plasma-detect-gpsd-correctly.diff
  * used return value of gps_open() as condition instead of checking
    m_gpsdata, that fix plasmoid crash when gpsd not running. (bnc#722133)
* Wed Nov  2 2011 dmueller@suse.de
- update to 4.7.3
  * see http://kde.org/announcements/changelogs/changelog4_7_2to4_7_3.php for details
* Wed Nov  2 2011 wstephenson@suse.com
- Don't corrupt Plasma's global config from Power Management
* Wed Nov  2 2011 dmueller@suse.de
- rediff 4.7 branch diff to include fix for regression kde#285347
* Fri Oct 21 2011 coolo@suse.com
- kdm: don't even look for grub-set-default, we won't need it
* Wed Oct 19 2011 wstephenson@suse.com
- Add 4.7 branch diff
* Thu Oct 13 2011 coolo@suse.com
- respect $KDE_NETWORKMANAGER_DISABLED before deciding if users
  want an always red symbol in their plasma config
  (plasma-disable-networkmanager.diff)
* Thu Oct 13 2011 coolo@suse.com
- fix branding requires for kwin and kdm
* Wed Oct 12 2011 coolo@suse.com
- take out the corona patch, it should be in branding-openSUSE
- put plasma files in branding-upstream and require specific version
  of it from branding packages
* Wed Oct  5 2011 coolo@suse.com
- remove duplicated icons from panel layout
* Mon Oct  3 2011 coolo@suse.com
- google-gadgets is gone from 12.1
* Sun Oct  2 2011 dmueller@suse.de
- update to 4.7.2
  * see http://kde.org/announcements/changelogs/changelog4_7_1to4_7_2.php for details
- remove patch from upstream
* Wed Sep 21 2011 eich@suse.com
- Create new macro to make sure dm script always gets installed in
  ${_prefix}/lib. Neither ${_libdir} nor ${_libexecdir} qualify across
  all SUSE products.
* Fri Sep 16 2011 ctrippe@opensuse.org
- Report the correct height/width of the panel (bnc#653499)
* Wed Sep 14 2011 javier@opensuse.org
- Add upstream patch to improve kwin performance.
* Mon Sep  5 2011 eich@suse.com
- Add %%_libdir/X11 to the list of dirs.
* Thu Sep  1 2011 dmueller@suse.de
- update to 4.7.1
  * Bugfixes over KDE 4.7.0
  * see http://kde.org/announcements/changelogs/changelog4_7_0to4_7_1.php for details
* Wed Aug 31 2011 eich@suse.com
- %%{_libdir}/X11/displaymanagers is no config file.
* Tue Aug 30 2011 eich@suse.com
- Changed %%{_sysconfdir}/X11/displaymanagers to
  %%{_libdir}/X11/displaymanagers.
* Tue Aug 30 2011 eich@suse.com
- add missing "%%dir %%{_sysconfdir}/X11/displaymanagers"
  to specfile.
* Tue Aug 30 2011 idonmez@suse.com
- Refresh kde-workspace-4.7-branch.patch
  * Add a fake NetworkManager 0.9 backend to Solid
* Thu Aug 25 2011 eich@suse.de
- kdm: Add startup script file to be sourced by /etc/xinit.d/xdm.
  The display manager stratup script /etc/init.d/xdm should not
  contain any code specific to a display manager. Instead such code
  should live in a script file supplied by the specific dm which
  is sourced by the start script. Those script files will live
  in /etc/X11/displaymanagers/.
* Wed Aug 24 2011 idonmez@novell.com
- Refresh kde-workspace-4.7-branch.patch:
  * Fix kwin maximize problem with already maximized windows
  * Improvements to kwin memory management
* Fri Aug 12 2011 idonmez@novell.com
- Add kde-workspace-4.7-branch.patch: sync with 4.7 branch
  * Fix kwin crash inside qemu/kvm
  * Fix system tray not collapsing when removing applets
  * Implement and fix scaled XRender shadows
* Tue Aug  2 2011 idonmez@novell.com
- Refresh and apply plasma-branding-defaults-corona.diff,
  plasma-kickoff-newly-collapsing.diff
- Drop kdm-themer-wallpaper-sizes.diff, fixed in upstream in
  different way.
* Fri Jul 22 2011 dmueller@suse.de
- update to 4.7.0
  * Small fixes over KDE 4.7 RC2
  * see http://kde.org/announcements/4.7 for details
* Fri Jul 22 2011 idonmez@novell.com
- Remove unneeded security filters from rpmlintrc
* Fri Jul 22 2011 idonmez@novell.com
- Add BuildRequires on libprison-devel to add barcode support to
  klipper.
* Fri Jul 22 2011 idonmez@novell.com
- Obsolete/Provide kdeaccessibility package
* Thu Jul 21 2011 idonmez@novell.com
- Update to 4.6.95
* Fri Jul  1 2011 dmueller@suse.de
- update to 4.6.5
  * Bugfixes over KDE 4.6.5
  * see http://kde.org/announcements/changelogs/changelog4_6_4to4_6_5.php for details
* Sat Jun  4 2011 eich@suse.de
- Add upstream patch:
  Enable_direct_rendering_for_all_Mesa_drivers.diff
  * This enables direct rendering for all Mesa drivers requiring
    at least Mesa 7.10.
    This allows to remove a revert patch to Mesa. This patch allows us
    to remove a patch to Mesa which restores an older version of the
    renderer string.
    It will become obsolete once a new version of kwin is checked in.
* Thu Jun  2 2011 dmueller@suse.de
- update to 4.6.4
  * Bugfixes over KDE 4.6.3
  * see http://kde.org/announcements/changelogs/changelog4_6_3to4_6_4.php for details
* Wed May  4 2011 tittiatcoke@gmail.com
- Added Patch for NM 0.9 compatibility (only for Factory)
* Thu Apr 28 2011 dmueller@suse.de
- update to 4.6.3
  * Bugfixes over KDE 4.6.2
  * see http://kde.org/announcements/changelogs/changelog4_6_2to4_6_3.php for details
* Tue Apr 19 2011 coolo@opensuse.org
- port gspd client to new API
* Sat Apr 16 2011 xgpub@tellas.gr
- Fix multihead support (bko#256242)
* Sat Apr  9 2011 wstephenson@novell.com
- Fix Plasma assert when using Akonadi caliendar (bko#261593)
* Fri Apr  8 2011 wstephenson@novell.com
- Patch out incorrect FreeBSD shutdown syntax (bko#270228)
* Sun Apr  3 2011 gryffus@hkfree.org
- Remove blacklist of Intel 945GM from KWin Blur effect (kwin blacklist removed upstream)
* Fri Apr  1 2011 dmueller@suse.de
- update to 4.6.2
  * Bugfixes over KDE 4.6.1
  * see http://kde.org/announcements/changelogs/changelog4_6_1to4_6_2.php for details
* Tue Mar  8 2011 dmueller@suse.de
- update to 4.6.1
  * Bugfixes over KDE 4.6.0
  * see http://kde.org/announcements/changelogs/changelog4_6_0to4_6_1.php for details
- remove upstreamed patches
* Sat Feb 26 2011 coolo@novell.com
- simplify perl update script for blur blacklist (bnc#675388)
* Thu Feb 24 2011 coolo@novell.com
- readd global shortcut Alt+f1 for launcher (bnc#637583)
* Fri Feb 18 2011 wstephenson@novell.com
- Blacklist Intel 945GM from KWin Blur effect
* Thu Feb 17 2011 wstephenson@novell.com
- Reenable some patches:
  * Add some default launchers to new panels
  * Enable fingerprint support in KDM
* Tue Feb 15 2011 dmueller@suse.de
- remove blacklisting of unauthorized rpmlintrc errors
* Mon Feb 14 2011 remur@gmx.net
- added powerdevil branchupdate to fix various bugs
  bko264534, bko264730, bko257948, bko257948, bnc670851
* Fri Feb 11 2011 ctrippe@gmx.net
- Enable the reduced menu depth feature and add the recently
  installed menu entry (bnc#664086)
* Fri Feb 11 2011 tittiatcoke@gmail.com
- Added upstream patch for DPMS management (bko#264730)
* Sat Feb  5 2011 ctrippe@gmx.net
- Report the correct height/width of the panel (bnc#653499)
* Fri Feb  4 2011 wstephenson@novell.com
- Backport patch to prevent the clock calendar widget spawning
  Akonadi (bnc#661844)
* Wed Jan 19 2011 dmueller@suse.de
- update to 4.6.0
  * For highlights, see http://kde.org/announcements/4.6
* Tue Jan  4 2011 dmueller@suse.de
- update to 4.5.95
  * KDE 4.6 RC2
  * no upstream changelog available.
* Sun Jan  2 2011 abrouwers@gmail.com
- Horos is the default upstream wallpaper for 4.6
* Wed Dec 22 2010 dmueller@suse.de
- update to 4.5.90
  * KDE 4.6 RC1
  * no upstream changelog available.
* Wed Dec 15 2010 wstephenson@novell.com
- Don't crash on panel relayout (bko#259793)
* Fri Dec  3 2010 dmueller@suse.de
- update to 4.5.85
  * KDE 4.6 Beta2
  * Final Beta before RC, various fixes from Beta1
  * no upstream changelog available.
* Tue Nov 30 2010 hpj@urpla.net
- apply patch (no-randr-1.3.diff) that allows to build with openSUSE 11.1
* Wed Nov 24 2010 coolo@novell.com
- update to 11.4 branding
* Sun Nov 21 2010 coolo@novell.com
- disable enable-final for the moment and sort buildrequires
* Fri Nov 19 2010 dmueller@suse.de
- update to 4.5.80
  * KDE 4.6 Beta1
  * no upstream changelog available.
  * Removed patches
    kdebase-workspace-4.3.95-ck-shutdown.patch (upstream)
    plasma-new-default-panel.diff (upstream)
    plasma-plaindesktop.diff (no longer needed)
* Wed Nov 10 2010 coolo@novell.com
- fix file list
* Thu Oct 28 2010 dmueller@suse.de
- update to 4.5.3
  * see http://kde.org/announcements/changelogs/changelog4_5_2to4_5_3.php for details
* Thu Sep 30 2010 dmueller@suse.de
- update to 4.5.2
  * see http://kde.org/announcements/changelogs/changelog4_5_1to4_5_2.php for details
* Mon Sep 27 2010 wittemar@googlemail.com
- Split liboxygenstyle in an own package
* Tue Sep  7 2010 llunak@novell.com
- DISPLAYMANAGER_ROOT_LOGIN_LOCAL in /etc/sysconfig (bnc#626433)
* Fri Aug 27 2010 dmueller@suse.de
- update to 4.5.1
  * see http://kde.org/announcements/changelogs/changelog4_5_0to4_5_1.php for details
* Fri Aug 13 2010 dmueller@suse.de
- update 4_5_BRANCH.diff:
  * disable MALLOC_CHECK_ export
* Sun Aug  8 2010 beineri@opensuse.org
- port applets part of plasma-branding-defaults.diff
* Thu Jul 29 2010 dmueller@suse.de
- update to 4.5.0
  * KDE 4.5.0 final (version bump over RC3)
* Fri Jul 23 2010 dmueller@suse.de
- update to 4.4.95
  * KDE 4.5 RC3 (not announced)
  * critical fixes for 4.5.0 release
* Fri Jul 16 2010 dmueller@suse.de
- update to 4.4.93svn1149349
* Wed Jul  7 2010 dmueller@suse.de
- update to 4.4.5
  * bugfixes over 4.4.4
  * see http://kde.org/announcements/changelogs/changelog4_4_4to4_4_5.php for details
* Mon Jul  5 2010 dmueller@suse.de
- update 4_4_BRANCH.diff (hand-picked fixes from 4.4 branch):
  * Show battery and device notifier applets in the system tray
    by default (bnc#597162)
* Mon Jun 21 2010 llunak@novell.com
- fix splash not using same background geometry as KDM and Plasma
  on weird aspect ratio screens, resulting in ugly changes
  during KDE startup
* Fri Jun 18 2010 dmueller@suse.de
- update to 4.4.4
  * bugfixes over 4.4.3
  * see http://kde.org/announcements/changelogs/changelog4_4_3to4_4_ 4.php for details
  * for most modules only version number as a change (4_4_BRANCH.diff already contained the diff
* Thu Jun 17 2010 llunak@novell.com
- fix parsing intel driver version, making compositing enabled
  again on suitable intel systems (bnc#605498)
* Thu Jun 17 2010 wstephenson@novell.com
- Fixes from Plasma 4.4 branch:
  * Weather widget crash (bko#240032)
  * Crash when moving widget from panel to desktop
    (bko#240399, bko#241099)
  * Crash when right clicking deleted application in Kickoff menu
    (bko#227601)
  * Panel spacer Set Flexible Size setting not saved (bko#232424)
  * Crash when removing items from the system tray (bko#235066)
  * Show battery and device notifier applets in the system tray
    by default (bnc#597162)
* Fri May 21 2010 cmorve69@yahoo.es
- Fix build-compare
* Wed May 19 2010 llunak@novell.com
- do not leave clipboard empty when an app quits (kde#229052)
* Tue May 18 2010 llunak@novell.com
- avoid system monitor crashes (bnc#597156)
* Mon May 17 2010 llunak@novell.com
- update 4_4_BRANCH.diff: various fixes, translation updates
* Fri May 14 2010 llunak@novell.com
- update 4_4_BRANCH.diff: ignore stale utmp entries (bnc#600812)
* Thu Apr 29 2010 dmueller@suse.de
- update to 4.4.3
  * bugfixes over 4.4.2
  * see http://kde.org/announcements/changelogs/changelog4_4_2to4_4_3.php for details
* Tue Apr 27 2010 aj@suse.de
- Fix some obsoletes/provides to not be self-obsoletes.
- Fix branding requires to require 11.3 on 11.3.
* Thu Apr 15 2010 llunak@novell.com
- make shutdown/restart work in logout dialog also with GDM
    (bnc#593269, bnc#331569)
* Fri Mar 26 2010 dmueller@suse.de
- update to 4.4.2
  * bugfixes over 4.4.1
  * see http://kde.org/announcements/changelogs/changelog4_4_1to4_4_2.php for details
* Tue Mar 23 2010 llunak@novell.com
- CVE-2010-0436 (bnc#584223)
* Tue Mar 16 2010 llunak@novell.com
- include Aurorae theme docs in the kwin package
* Mon Mar 15 2010 llunak@novell.com
- update kdm theme fixes for bnc#533189
* Fri Mar  5 2010 llunak@novell.com
- fix problems when fingerprint support is enabled (bnc#533189)
* Fri Feb 26 2010 dmueller@suse.de
- update to 4.4.1
  * bugfixes over 4.4.0
  * see http://kde.org/announcements/changelogs/changelog4_4_0to4_4_1.php for details
* Sun Feb 14 2010 llunak@novell.com
- google-gadgets no longer build for 11.0, disable support
* Thu Feb  4 2010 dmueller@suse.de
- update to 4.4.0
  * Critical bugfixes only over 4.3.98
  * see http://www.kde.org/announcements/4.4/ for general overview
* Sun Jan 31 2010 dmueller@suse.de
- update to 4.3.98
  * see http://www.kde.org/announcements/announce-4.4-rc3.php for details
* Wed Jan 20 2010 dmueller@suse.de
- update to 4.3.95
  * see http://www.kde.org/announcements/announce-4.4-rc2.php for details
* Wed Jan 13 2010 llunak@novell.com
- move upstream splashscreen theme into -branding-upstream
- move upstream Air wallpaper into -branding-upstream
* Wed Jan  6 2010 dmueller@suse.de
- update to 4.3.90
  * see http://www.kde.org/announcements/announce-4.4-rc1.php for details
* Fri Dec 18 2009 dmueller@suse.de
- update to 4.3.85
  * see http://www.kde.org/announcements/announce-4.4-beta2.php for details
* Fri Dec  4 2009 dmueller@suse.de
- update to 4.3.80:
  * see http://techbase.kde.org/Schedules/KDE4/4.4_Feature_Plan
* Fri Nov 20 2009 beineri@opensuse.org
- make patches apply without fuzz
* Mon Nov  2 2009 dmueller@suse.de
- update to 4.3.3
  * see http://kde.org/announcements/changelogs/changelog4_3_2to4_3_3.php for details
* Wed Oct  7 2009 llunak@novell.com  
- do not hide file job progress windows (bnc#533001)
* Wed Oct  7 2009 coolo@novell.com  
- also obsolete powerdevil-lang (bnc#539543)
* Wed Sep 30 2009 llunak@novell.com
- fix PrintScreen (bnc#504714)
* Thu Sep 24 2009 beineri@opensuse.org
- update 4_3_BRANCH.diff:
  * several small memory leak fixes in kcm modules
  * kdm theme (rendering) fixes
  * fix kwin "Special Settings" icons and some effect flaws
  * fix panel size changes when en/disabling effects (kde#184905)
  * plasma: service runner and tasks plasmoid size fixes
* Tue Sep 15 2009 beineri@opensuse.org
- fix low disk space notifier popup layout (bnc#533146)
- move kwin cube cap to kdebase4-workspace-branding-upstream
- don't show "hidden" wallpapers in selection dialog
* Wed Sep  9 2009 beineri@opensuse.org
- update 4_3_BRANCH.diff:
  * powerdevil: revert to previous dimm-state (bnc#535940)
  * plasma: several performance and other bug fixes
  * kwin: coverswitch/boxswitch effect crash fixes (kde#184602)
* Fri Aug 28 2009 dmueller@suse.de
- update to 4.3.1
  * see http://kde.org/announcements/changelogs/changelog4_3_0to4_3_1.php for details
* Fri Aug 28 2009 beineri@opensuse.org
- recommend python-kdebase4 package (bnc#535057)
- start root kcm modules detached (bnc#483768)
* Wed Aug 26 2009 mls@suse.de
- make patch0 usage consistent
* Sun Aug 23 2009 beineri@opensuse.org
- fix Plasma config exploding/start-up slow down (kde#203058)
- disable Nepomuk search runner if Nepomuk is disabled
- several KWin desktop effects fixes
* Tue Aug 18 2009 beineri@opensuse.org
- remove recommendation on kde4-printer-applet again
* Tue Aug 18 2009 llunak@suse.cz
- put the randr patch back again, it's still not upstream
  (bnc#468931)
* Fri Aug 14 2009 beineri@opensuse.org
- properly integrate lock/logout plasmoid option into config dialog
- add config for "Recently Installed" & collapsing menu (bnc#523358)
- add support to recreate default panel on empty desktop
- add "Configure Plasma..." option to non-zoomed desktop cashew
* Wed Aug 12 2009 wstephenson@novell.com
- branch update (network interface speed reporting fixes)
* Tue Aug 11 2009 beineri@opensuse.org
- fix file conflict between -workspace and -wallpapers
* Tue Aug 11 2009 wstephenson@novell.com
- branch update (libsolidcontrol crash fix)
* Mon Aug 10 2009 beineri@opensuse.org
- add sysconfig.displaymanager-kdm to kdm-branding-upstream package
* Wed Aug  5 2009 llunak@suse.cz
- branch update (no kwin abort because of harmless X errors)
* Sat Aug  1 2009 beineri@opensuse.org
- prefer Firefox over Konqueror as panel default (bnc#513892)
* Thu Jul 30 2009 beineri@opensuse.org
- ported and reenabled systemsettings-root-kcm.diff (bnc#526199)
* Wed Jul 29 2009 dmueller@suse.de
- update to 4.3.0
  * see http://kde.org/announcements/4.3 for details
* Fri Jul 24 2009 beineri@opensuse.org
- recommend kde4-printer-applet
* Tue Jul 21 2009 dmueller@suse.de
- update to 4.2.98
* Tue Jul 21 2009 llunak@novell.com
- add protection against OOM-killer from KDE trunk
* Wed Jul  8 2009 dmueller@suse.de
- update to 4.2.96
* Thu Jul  2 2009 beineri@opensuse.org
- fix ksysguardd not finding its config file (bnc#518382)
* Fri Jun 26 2009 llunak@suse.cz
- update 4_3_BRANCH.diff to fix build
* Wed Jun 24 2009 dmueller@suse.de
- update to 4.2.95
* Sat Jun 20 2009 beineri@opensuse.org
- drop kde4- package prefixes
* Wed Jun 10 2009 llunak@suse.cz
- add rckdm symlink, like in KDE3
* Tue Jun  9 2009 llunak@suse.cz
- add init.d files for ksysguardd (bnc#405644)
* Wed Jun  3 2009 llunak@suse.cz
- fix Geeko placement in titlebar (bnc#502512)
* Wed May 27 2009 dmueller@suse.de
- update to 4.2.88svn973768
* Wed May 27 2009 ro@suse.de
- genkdmconf: skip warning message for oldkde != share/config
  (we use share/kde4/config)
- genkdmconf: cleanup backup files if unchanged
* Mon May 25 2009 adrian@suse.de
- Add ConsoleKit-x11 requires to kde4-kdm
  (kdm fails to login user otherwise)
* Mon May 18 2009 coolo@novell.com
- remove hotplug-kde3 patch, it was never included in > 4.0 packages
* Fri May 15 2009 coolo@suse.de
- (Beineri) split plasma patch into smaller chunks
- remove patches that are no longer necessary
- rediff kdm patches
* Thu May 14 2009 dmueller@suse.de
- update to 4.2.85 (KDE 4.3 beta1)
* Wed May 13 2009 dmueller@suse.de
- fix dependencies of subpackages
* Thu Apr 30 2009 dmueller@suse.de
- update to 4.2.3
  * see http://kde.org/announcements/changelogs/changelog4_2_2to4_2_3.php
* Sat Apr  4 2009 coolo@suse.de
- refresh all patches to fix build
* Thu Mar 26 2009 dmueller@suse.de
- update to 4.2.2
  * see http://kde.org/announcements/changelogs/changelog4_2_1to4_2_2.php
* Sun Mar 15 2009 coolo@suse.de
- update 4_2_BRANCH.diff - several kickoff fixes
* Fri Mar  6 2009 coolo@suse.de
- add spec file to build python applet engine
* Thu Mar  5 2009 coolo@suse.de
- cmake 2.6.3 expects the cmake files somewhere else
* Thu Feb 26 2009 dmueller@suse.de
- update to 4.2.1
  * see http://kde.org/announcements/changelogs/changelog4_2_0to4_2_1.php
* Thu Feb 26 2009 dmueller@suse.de
- disable session registration in kdm, the scripts around
  it do it already (bnc#478661)
* Wed Feb 18 2009 dmueller@suse.de
- update branch diff
* Wed Feb 18 2009 stbinner@suse.de
- readd "Recently Installed" and collapsing sub-folders to Kickoff
* Tue Feb 17 2009 stbinner@suse.de
- bump branding version for 11.2/Factory
* Thu Feb 12 2009 coolo@suse.de
- require pam-config in kdm
* Thu Feb 12 2009 coolo@suse.de
- branch diff update: kdm crash fix with qt 4.5
* Thu Feb 12 2009 coolo@suse.de
- make sure wallappers are only in either package
* Fri Feb  6 2009 stbinner@suse.de
- branch diff update: krunner, kwin and plasma bug fixes
* Tue Feb  3 2009 stbinner@suse.de
- re-add "plaindesktop" desktop containment type (bnc#471219)
- make "Lock/Logout" button order configurable again (bnc#468882)
- remove kde4-plasmoid-quickaccess obsolete again
* Wed Jan 28 2009 dmueller@suse.de
- update to KDE 4.2.0
* Wed Jan 21 2009 stbinner@suse.de
- split off kdebase4-workspace-google-gadgets sub-package
* Tue Jan 20 2009 stbinner@suse.de
- add knetworkmanager-kde4 to default panel if installed
- add YaST/package manager/Live CD installer/sysinfo to Kickoff
- support suse start menu button branding
* Sun Jan 18 2009 tpatzig@suse.de
- fixed solid-bluetooth for bluez4 support
* Wed Jan 14 2009 llunak@suse.cz
- increase ServerTimeout to 60 for KDM (bnc#462478)
* Tue Jan 13 2009 stbinner@suse.de
- update to KDE 4.1.96 (4.2 RC1)
* Fri Jan  9 2009 dmueller@suse.de
- update to KDE 4.1.87 (KDE 4.2 Januar snapshot)
* Fri Jan  9 2009 llunak@suse.cz
- review changes
* Wed Jan  7 2009 hoodedone@gmail.com
- backport krdb fix for bloated libraryPath in Trolltech.conf
  * added one-time cleanup to kconf_update
* Mon Jan  5 2009 llunak@suse.cz
- Revert change in KDM that made it also grab the mouse, which
  prevents xvkbd from working on tablet PCs (bnc#445726).
* Sat Jan  3 2009 stbinner@suse.de
- fix missing device notifiert icon in tooltip (bnc#458532)
* Wed Dec 17 2008 stbinner@suse.de
- Kickoff: check if default/previous favorites (still) exist
* Wed Dec 17 2008 llunak@suse.cz
- fix various bugs in randr12 support in the control module
  that make it more than barely useful (bnc#383187)
* Tue Dec 16 2008 stbinner@suse.de
- versionized split-provides are not supported
* Tue Dec  2 2008 coolo@suse.de
- fix checkerboard startup of X server
* Mon Dec  1 2008 dmueller@suse.de
- fix duplicate packaged files
* Thu Nov 20 2008 stbinner@suse.de
- add SLE provides/obsoletes
* Thu Nov 20 2008 llunak@suse.cz
- make also logout dialog use suspend code that lock (bnc#326848)
* Wed Nov 19 2008 llunak@suse.cz
- disable plasma backported suspend code (bnc#326848, bnc#444793)
* Fri Nov 14 2008 dmueller@suse.de
- add missing quoting (bnc#444742)
- fix greeter plugin splitting so that kde3 only installation
  is possible
* Tue Nov 11 2008 stbinner@suse.de
- update Plasma powermanagement dataengine
* Mon Nov 10 2008 dmueller@suse.de
- kdm: make generic plugin use the same pam config
- kdm: switch to generic plugin if fingerprint pam module is used
* Sun Nov  9 2008 stbinner@suse.de
- offer to add default plasmoids when adding first panel
* Fri Nov  7 2008 llunak@suse.cz
- make khotkeys work (i.e. printscreen shortcut) (bnc#420480)
* Fri Nov  7 2008 stbinner@suse.de
- don't hardcode homepage of Kickoff branding button
- Lock/Logout plasmoid: configurable order (bnc#437703)
- read KDE3-style <wallpaper>.desktop files (bnc#436439)
- add NetworkManager plasmoid to default panel if installed
* Thu Nov  6 2008 stbinner@suse.de
- fix kdm session button select (bnc#387062)
* Thu Nov  6 2008 llunak@suse.cz
- require more recent nvidia driver (173.14.12 and up)
  for compositing to be enabled by default
* Tue Nov  4 2008 stbinner@suse.de
- backport tooltips for more Plasma widgets (bnc#430792)
* Mon Nov  3 2008 llunak@suse.cz
- update from randr branch (bnc#427645)
- update from kwin branch (sync with 4.1 branch)
* Mon Nov  3 2008 stbinner@suse.de
- update to 4.1.3
  * see http://kde.org/announcements/changelogs/changelog4_1_2to4_1_3.php
* Thu Oct 30 2008 stbinner@suse.de
- kde4-kwin: "Provides: windowmanager"
* Mon Oct 27 2008 stbinner@suse.de
- backport of battery plasmoid popup
* Mon Oct 27 2008 wstephenson@suse.de
- More fixes to Solid/Control from upstream
* Mon Oct 27 2008 stbinner@suse.de
- backport of refactored system tray code
* Sun Oct 26 2008 stbinner@suse.de
- systemsettings: start root-only kcms non-embedded (bnc#396186)
- backport tooltip manager (regression compared to 4.0)
- make plain desktop the default desktop containment
- backport panel auto-hide fixes (eg bnc#432691)
- fix incorrect shutdown on logout (bnc#396248)
* Wed Oct 22 2008 stbinner@suse.de
- debug_package_requires depend also on %%release
* Mon Oct 20 2008 stbinner@suse.de
- fix build on s390/s390x
* Tue Oct  7 2008 sbrabec@suse.cz
- Conflict with other branding providers (FATE#304881).
* Thu Oct  2 2008 llunak@suse.cz
- update from kwin branch (bnc#430472,bnc#426171,bnc#431386,etc.)
* Wed Oct  1 2008 lrupp@suse.de
- remove conflict with NLD theme
* Tue Sep 30 2008 llunak@suse.cz
- shorten decoration stripes to not mix with logo (bnc#410698)
* Mon Sep 29 2008 wstephenson@suse.de
- Adapt Solid::Control and backend for NetworkManager 0.7-r4060
* Sun Sep 28 2008 stbinner@suse.de
- fix wallpaper configuration (bnc#429971)
* Thu Sep 25 2008 dmueller@suse.de
- update to 4.1.2
  * see http://kde.org/announcements/changelogs/changelog4_1_1to4_1_2.php
* Thu Sep 25 2008 llunak@suse.cz
- disable detecting monitor changes since X can't detect them
  automatically and can't take polling that well either(bnc#427645)
* Wed Sep 24 2008 stbinner@suse.de
- add diffs to plasma-4.1-openSUSE branch for backports and more:
  * allow to set folder view as desktop activity
  * allow to change desktop to one without toolbox
  * option to have panels hide automatically
  * option to have windows cover panels
* Thu Sep 18 2008 stbinner@suse.de
- improve branding package definitions
* Wed Sep 17 2008 llunak@suse.cz
- improve detection of whether the system is capable of decent
  compositing (fate#304756)
* Wed Sep 17 2008 llunak@suse.cz
- fix handling of Display key (fate#4147)
* Mon Sep 15 2008 dmueller@suse.de
- adjust buildrequires
* Fri Sep 12 2008 llunak@suse.cz
- support for Display key (fate#4147)
* Thu Sep 11 2008 llunak@suse.cz
- update kwin branch (e.g. bnc#422532)
* Thu Sep 11 2008 llunak@suse.cz
- disable the patch setting 2 virtual desktops by default
* Thu Sep 11 2008 llunak@suse.cz
- kcontrol/randr branch for randr12 features and fixes
  (e.g. fate#304764)
* Mon Sep  8 2008 stbinner@suse.de
- update branch diff
* Thu Sep  4 2008 llunak@suse.cz
- temporarily disable kwin self-check until the problem is found
  (bnc#422532)
* Tue Sep  2 2008 dmueller@suse.de
- add libsensors4 support
* Tue Sep  2 2008 llunak@suse.cz
- switch to the kwin branch for 11.1 (e.g. bnc#418772)
* Thu Aug 28 2008 dmueller@suse.de
- update to 4.1.1
  * see http://kde.org/announcements/changelogs/changelog4_1to4_1_1.php
* Wed Aug 20 2008 dmueller@suse.de
- update branch diff
- rediff patch of last change entry to apply properly
* Wed Aug 20 2008 llunak@suse.cz
- move WM selection option to a better place in systemsettings
* Sat Aug 16 2008 stbinner@suse.de
- branch diff update
- fix debuginfo requires
* Mon Aug 11 2008 coolo@suse.de
- exclude kdm pictures in branding packages
* Wed Jul 23 2008 dmueller@suse.de
- update to 4.1.0
* Fri Jul 18 2008 dmueller@suse.de
- update to 4.0.99
* Tue Jul 15 2008 stbinner@suse.de
- port more SUSE-specific changes/features from 4.0 to 4.1 Plasma
* Tue Jul 15 2008 dmueller@suse.de
- do not link ksysguardd against kdefakes to reduce dependencies (bnc#406895)
* Fri Jul 11 2008 stbinner@suse.de
- update to 4.0.98
* Mon Jul  7 2008 dmueller@suse.de
- update to 4.0.85
* Wed Jul  2 2008 schwab@suse.de
- Fix broken use of ptrace.
* Mon Jun 30 2008 dmueller@suse.de
- branch diff update
* Tue Jun 24 2008 dmueller@suse.de
- update to 4.0.83
* Tue Jun 24 2008 stbinner@suse.de
- add plasma.diff for basic branding and integration
* Mon Jun 23 2008 dmueller@suse.de
- update to 4.0.82
* Wed Jun  4 2008 wstephenson@suse.de
- minimal Solid NetworkManager 0.7 backend fixes network status is
  always unknown (bnc#397072)
* Mon Jun  2 2008 dmueller@suse.de
- don't deinstall KDE3 due to kdebase3-ksysguard conflict
- fix panel sizing issue
* Tue May 27 2008 dmueller@suse.de
- call kde4-migrate if present (bnc#372170)
* Mon May 26 2008 stbinner@suse.de
- backport unmounting in device notifier (bnc#391223)
* Mon May 26 2008 stbinner@suse.de
- fix "switch user" doesn't work always (bnc#392269)
- fix logout from "Classic Menu Style" lacks power off/restart/
  standby/suspend options (bnc#391765)
* Fri May 23 2008 stbinner@suse.de
- copy suspend parts from ksmserver logout dialog (bnc#390147)
- make drop of local files to Plasma desktop copy to ~/Desktop
* Wed May 21 2008 stbinner@suse.de
- add option how to render desktop icon labels (bnc#382747)
- fix "save session" menu item missing in kmenu (bnc#383757)
- add sysinfo:/ entry to start menu in "Computer" tab as on KDE3
- make krunner search prefer KDE4 applications (bnc#381849)
- hidden option to disable desktop toolbox (bnc#393211)
* Mon May 19 2008 stbinner@suse.de
- make ksmserver shutdown dialog use Plasma text color (bnc#391828)
- fix opening within Firefox and Mozilla from Klipper (bnc#384203)
* Fri May 16 2008 llunak@suse.cz
- rename Oxygen window decoration to Ozone
* Fri May 16 2008 llunak@suse.cz
- support for KDE3 hotplug actions (bnc#378338)
* Fri May 16 2008 dkukawka@suse.de
- fixed rotate-wacom-pointers.diff to work with current xsetwacom
  (bnc#391440)
* Wed May 14 2008 stbinner@suse.de
- add ported rotate-wacom-pointers.diff (bnc#385149)
- correct ksysguardd package name and require it
* Tue May 13 2008 dmueller@suse.de
- kdm4: terminate local x servers by default (bnc#381672)
- kdm4: make delayed popup work again (bnc#381197)
* Tue May 13 2008 coolo@suse.de
- use the server cmd from sysconfig
* Mon May 12 2008 llunak@suse.cz
- fix possible ksmserver<->knotify deadlock during KDE startup
* Mon May 12 2008 llunak@suse.cz
- fix crash preventing setting of time/date (bnc#386429)
* Mon May 12 2008 coolo@suse.de
- set a preloader by default
* Fri May  9 2008 dmueller@suse.de
- fix kdm4 requiring root for shutdown
* Fri May  9 2008 stbinner@suse.de
- add Kontact/KDE4 instead of Kontact/KDE3 to Kickoff (bnc#386374)
- fix potential Plasma crash after deleting plasmoids (bnc#386462)
* Fri May  9 2008 llunak@suse.cz
- Administrator mode for date/time module, to make it usable
* Tue May  6 2008 dmueller@suse.de
- update to 4.0.4
  * http://kde.org/announcements/changelog_4_0_3to4_0_4.php
* Tue May  6 2008 dmueller@suse.de
- fix fileconflicts by introducing an upstream-branding
  package for kde4-kdm
* Fri May  2 2008 llunak@suse.cz
- Fix stacking problems in KWin (bnc#378773)
* Fri May  2 2008 llunak@suse.cz
- Add missing ICE check for ksmserver (bnc#384774)
* Mon Apr 28 2008 dmueller@suse.de
- fix focus issues in kde4-kdm (bnc#381501)
* Mon Apr 28 2008 stbinner@suse.de
- update Plasma diff from openSUSE Plasma branch: several bugfixes
  including bnc#381704, bnc#379082, bnc#382510, bnc#377728,
  bnc#382169, bnc#381191, bnc#382497
* Wed Apr 23 2008 dmueller@suse.de
- use radiobuttons for sessions menu (bnc#382138)
* Mon Apr 21 2008 dmueller@suse.de
- fix unknown icon on suspend (#bnc381194)
* Fri Apr 18 2008 llunak@suse.cz
- ksplashx changes needed for 11.0 splashscreen (bnc:#375581)
* Fri Apr 18 2008 dmueller@suse.de
- update 4_0_BRANCH.diff
  * memleak fixes in kwin and ksplashsimple
* Wed Apr 16 2008 stbinner@suse.de
- remove self conflict (bnc#379338)
* Mon Apr 14 2008 dmueller@suse.de
- fix file conflicts
* Mon Apr 14 2008 stbinner@suse.de
- improve logout, shutdown, restart confirmation and add countdown
- draw rounded background behind system tray windows
- don't align on every added file but only first run (bnc#379463)
* Mon Apr 14 2008 dmueller@suse.de
- add kgreeter_generic from 4.1 branch (fate#301954)
* Fri Apr 11 2008 dmueller@suse.de
- fix wallpaper not immediately updating (bnc#378771)
* Thu Apr 10 2008 stbinner@suse.de
- update Plasma diff from openSUSE Plasma branch:
  * draw desktop icons old style
  * remove useless desktop rubber band
  * add "(Un)Lock Widgets" and "Show Desktop" to and remove "Zoom
    Out" from desktop toolbox
  * fix not disappearing plasmoid handles (bnc#369994)
  * fix moving of rotated plasmoids (bnc#377108)
  * taskmanager: "Show only tasks from the current screen" option
  * digital-clock: add date tooltip, add "Show Seconds" option
  * pager: add window icons support
  * kickoff: backported KDE trunk appearance
- branding changes, split off kdebase4-workspace-branding-upstream
* Wed Apr  9 2008 llunak@suse.cz
- GUI for selecting the WM (bnc#332079)
* Mon Apr  7 2008 dmueller@suse.de
- fix devel splitting for kwin headers
- fix config installation dir
* Wed Apr  2 2008 stbinner@suse.de
- use Plasma diff created against branches/work/plasma-4.0-openSUSE
  which consolidates ported local patches, backported upstream and
  yet upstream uncommited features. This introduces:
  * moving of plasmoids on panels
  * adding and removing of panels
  * switching of start menu style
  * list newly installed applications within Kickoff
  * allow removing of uninstancable applets from a panel
  * Plasma theme selector, color change and tint support
* Mon Mar 31 2008 dmueller@suse.de
- update to 4.0.3
* Fri Mar 28 2008 llunak@suse.cz
- oxygen windecoration configurable colors (kde#152030)
* Tue Mar 11 2008 dmueller@suse.de
- 4_0_BRANCH.diff update, including
  * full screen handling fixes
  * repaint bugs with alien windows
* Fri Mar  7 2008 dmueller@suse.de
- fix kdm autologin and theming (bnc#365885)
- fix plasma crashes on startup (bnc#364977)
* Wed Feb 27 2008 dmueller@suse.de
- update to 4.0.2
* Mon Feb 18 2008 stbinner@suse.de
- update branch diff after Plasma backport week-end
- backport kickoff/simpleapplet view selection feature
* Mon Feb 11 2008 coolo@suse.de
- remove sessions already in other packages
* Mon Feb 11 2008 coolo@suse.de
- let kdm require workspace for the greeter plugins
* Fri Feb  8 2008 dmueller@suse.de
- build with PAM support (bnc#353531)
* Thu Feb  7 2008 stbinner@suse.de
- moved showdesktop & trash plasmoids to kdebase4-workspace-plamoids
* Wed Feb  6 2008 stbinner@suse.de
- fix file conflicts
* Mon Feb  4 2008 stbinner@suse.de
- update to final 4.0.1 tarball
- fix user session switching
- add location option to panel configuration dialog
- remove kinfocenter handbook
* Sun Feb  3 2008 stbinner@suse.de
- update to 4.0.1 release
- backport of panel size configuration dialog
- backport of display configuration for traditional launcher menu
- start Kickoff application browser always at top-level
- add "install all public kwin headers" patch
* Tue Jan 29 2008 stbinner@suse.de
- fix app menu starting and system tray icons regressions
* Sun Jan 27 2008 stbinner@suse.de
- add application menu shortening feature and fix alphabetical sort
* Wed Jan 23 2008 stbinner@suse.de
- update KDE_4_0_BRANCH.diff (incl. taskbar attention flash)
- don't migrate ~/Desktop icons to Dashboard which will not work
- migrate Trash.desktop to Trash plasmoid (added it for that)
- open Dashboard toolbox when Dashboard view is activated
- set GTK2_RC_FILES for better style of GTK applications
- fix locking of session (#355155)
* Sun Jan 20 2008 stbinner@suse.de
- update KDE_4_0_BRANCH.diff
- more SUSE-like default panel setup (size, icons, plasmoids):
  * adds showdesktop plasmoid
- backport taskbar plasmoid features:
  * use more than one row if there are many windows
  * option to show only the windows on current desktop
* Sat Jan 12 2008 stbinner@suse.de
- fix build
* Sat Jan  5 2008 stbinner@suse.de
- update to 4.0 release
* Wed Jan  2 2008 stbinner@suse.de
- update to 3.97.2
* Thu Dec 20 2007 stbinner@suse.de
- update to 3.97.1
* Sat Dec  8 2007 dmueller@suse.de
- update to 3.97.0
* Sat Dec  8 2007 stbinner@suse.de
- fix build
* Thu Dec  6 2007 dmueller@suse.de
- fix filelist
* Tue Dec  4 2007 dmueller@suse.de
- update to 3.96.3
* Sat Dec  1 2007 dmueller@suse.de
- update to 3.96.2
* Wed Nov 21 2007 dmueller@suse.de
- reenable OpenGL support
* Tue Nov 20 2007 dmueller@suse.de
- update to 3.96.0
* Thu Nov  1 2007 dmueller@suse.de
- updaste to 3.95.1
* Tue Oct 30 2007 dmueller@suse.de
- update to 3.95.0
* Tue Oct  2 2007 stbinner@suse.de
- update to 3.93.0.svn720097
* Wed Sep 26 2007 stbinner@suse.de
- update to 3.93.0.svn717339
* Thu Sep 13 2007 stbinner@suse.de
- update to 3.93.0.svn712052
* Sat Sep  1 2007 stbinner@suse.de
- update to KDE 4.0 Beta 2
* Thu Aug 23 2007 stbinner@suse.de
- update to 3.92.0.svn703920
* Thu Aug 16 2007 stbinner@suse.de
- update to 3.92.0.svn700775
* Wed Aug 15 2007 stbinner@suse.de
- fix more file conflicts
* Thu Aug  9 2007 stbinner@suse.de
- update to 3.92.0.svn697325
- fix file conflicts
* Sat Jul 28 2007 stbinner@suse.de
- update to KDE 4.0 Beta 1
* Thu Jul 19 2007 stbinner@suse.de
- don't show System Settings on non-KDE/KDE3 desktop
* Mon Jul 16 2007 stbinner@suse.de
- use the non generic lib version for libkonq
* Thu Jul 12 2007 stbinner@suse.de
- update to 3.91.0.svn672298
* Sat Jun 23 2007 stbinner@suse.de
- update to 3.90.1.svn679137
* Fri Jun  8 2007 stbinner@suse.de
- update to 3.90.1.svn670093
* Mon Jun  4 2007 stbinner@suse.de
- fix build
* Fri Jun  1 2007 coolo@suse.de
- simplify spec file by using macros from kde4-filesystem
* Wed May 23 2007 stbinner@suse.de
- run %%fdupes
- fix prefix of two bins
* Wed May 16 2007 olh@suse.de
- Buildrequires libusb -> libusb-devel
* Tue May 15 2007 stbinner@suse.de
- show .desktop files of kdebase4-runtime only in a KDE session
* Sat May 12 2007 stbinner@suse.de
- libkdeinit -> libkdeinit4
* Thu May 10 2007 stbinner@suse.de
- fix package file conflicts
* Mon May  7 2007 stbinner@suse.de
- initial package in abuild
